@@ -112,7 +112,9 @@ def write_mono(f, data, CC, CFLAGS, OS):
 	if OS == 'mingw' or OS == 'cygwin' or OS == 'windows':
 		PROG += '.exe'
 	if OS == 'tb':
-		EXTRA = '''VPATH = "./ $(shell find ../ -type d) ./"
+		EXTRA = '''
+include ../../etc/makerules
+VPATH = "./ $(shell find ../ -type d) ./"
 '''
 		global HASMAKERULES
 		HASMAKERULES = '#'
@@ -120,10 +122,10 @@ def write_mono(f, data, CC, CFLAGS, OS):
 		EXTRA = ''
 
 	f.write('''#Makefiile by gen_konoha.py
-CC = %s
-CFLAGS = %s
-%sLDLIBS = %s
+%sCC = %s
 %s
+CFLAGS += %s
+%sLDLIBS = %s
 
 program = %s
 library =
@@ -131,7 +133,7 @@ library =
 .PHONY: all
 all: $(program)
 
-''' % (CC, CFLAGS, HASMAKERULES, osldlibs(data,OS), EXTRA, PROG))
+''' % (HASMAKERULES, CC, EXTRA, CFLAGS, HASMAKERULES, osldlibs(data,OS), PROG))
 	
 	write_makeobjs(f, data)
 	
@@ -148,6 +150,8 @@ $(program): $(objs) konoha.o
 def gen_makefile(bdir, data):
 	if 'tb' in data.OPTIONS:
 		f = open(bdir + '/tbmx1/makefile', 'w')
+	if 'mingw' in data.OPTIONS:
+		f = open(bdir + '/mingw/makefile', 'w')
 	else:
 		f = open(bdir + '/build/Makefile', 'w')
 	CC = "gcc"
@@ -169,8 +173,8 @@ def gen_makefile(bdir, data):
 			CFLAGS += ' -DKONOHA_OS__MACOSX'
 		elif l == 'mingw':
 			OS = 'mingw'
-			CFLAGS = CFLAGS.replace(" -fPIC", "")
-			CFLAGS += ' -DKONOHA_OS__MINGW'
+			CFLAGS = CFLAGS.replace(" -fPIC", '')
+			CFLAGS += ' -I"include" -DKONOHA_OS__MINGW'
 		elif l == 'cygwin':
 			OS = 'cygwin'
 			CFLAGS = CFLAGS.replace(" -fPIC", "")
@@ -180,6 +184,9 @@ def gen_makefile(bdir, data):
 			HASMAKERULES = '#'
 			CFLAGS += ' -I/usr/local/te/include -I"../include" -DKONOHA_OS__TB'
 			data.OPTIONS.append("-mono")
+	
+	if '-liconv' in data.OPTIONS:
+		CFLAGS += ' -DKNH_USING_ICONV'
 
 	if '-mono' in data.OPTIONS :
 		CFLAGS = CFLAGS.replace(" -fPIC", "")
@@ -190,6 +197,11 @@ def gen_makefile(bdir, data):
 		write_dll(f, data, CC, CFLAGS, OS)
 		
 	f.write('''
+
+.PHONY: dist
+dist:
+	$(RM) -rf $(objs) konoha.o
+
 .PHONY: clean
 clean:
 	$(RM) -rf $(objs) $(program) $(library) konoha.o 
