@@ -211,7 +211,7 @@ knh_index_t knh_dict_findb_between(knh_dict_t *a, knh_bytes_t key, size_t sp, si
 {
 	L_TAIL:;
 	if(ep - sp < UNSORTED_MAXSIZ) {
-		knh_index_t i;
+		size_t i;
 		for(i = sp; i < ep; i++) {
 			if(knh_String_equals(a[i].key, key)) return i;
 		}
