@@ -42,157 +42,63 @@ extern "C" {
 /* ======================================================================== */
 /* [constructor] */
 
-
-/* ------------------------------------------------------------------------ */
 /* ======================================================================== */
 /* [method] */
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] Float! Float.opAdd:2(Float! v) */
+/* @method[CONST] Float! Float.opAdd(Float! v) */
 
-METHOD knh__Float_opAdd__2(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
-	Float *n = new_Float(ctx, ((sfp[0].f)->value + (sfp[1].f)->value));
-	KNH_RETURN(ctx, sfp, n);
+	KNH_RETURN_Float(ctx, sfp, ARG_float(sfp[0]) + ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opNeg() */
 
-METHOD knh__Float_opNg(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp)
 {
-	Float *n = new_Float(ctx, -((sfp[0].f)->value));
-	KNH_RETURN(ctx, sfp, n);
+	KNH_RETURN_Float(ctx, sfp, -(ARG_float(sfp[0])));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] Float! Float.opSub:2(Float! n) */
-
-METHOD knh__Float_opSub__2(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Float *n = new_Float(ctx, ((sfp[0].f)->value - (sfp[1].f)->value));
-	KNH_RETURN(ctx, sfp, n);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method[CONST] Float! Float.opMul:2(Float! n) */
-
-METHOD knh__Float_opMul__2(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Float *n = new_Float(ctx, ((sfp[0].f)->value * (sfp[1].f)->value));
-	KNH_RETURN(ctx, sfp, n);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method[CONST] Float! Float.opDiv:2(Float! n) */
-
-METHOD knh__Float_opDiv__2(Ctx *ctx, knh_sfp_t *sfp)
-{
-	Float *n = new_Float(ctx, ((sfp[0].f)->value / (sfp[1].f)->value));
-	KNH_RETURN(ctx, sfp, n);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method[VARARGS|CONST] Float! Float.opAdd(Float! v) */
-
-METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp)
-{
-	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	size_t i; 
-	knh_float_t n = (sfp[0].f)->value;
-	for(i = 1; i < ac; i++) {
-		n += (sfp[i].f)->value;
-	}
-	KNH_RETURN(ctx, sfp, new_Float(ctx, n));
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method[VARARGS|CONST] Float! Float.opSub(Float! n) */
+/* @method[CONST] Float! Float.opSub(Float! n) */
 
 METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	size_t i; 
-	knh_float_t n = (sfp[0].f)->value;
-	for(i = 1; i < ac; i++) {
-		n -= (sfp[i].f)->value;
-	}
-	KNH_RETURN(ctx, sfp, new_Float(ctx, n));
+	KNH_RETURN_Float(ctx, sfp, ARG_float(sfp[0]) - ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[VARARGS|CONST] Float! Float.opMul(Float! n) */
+/* @method[CONST] Float! Float.opMul(Float! n) */
 
 METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	size_t i; 
-	knh_float_t n = (sfp[0].f)->value;
-	for(i = 1; i < ac; i++) {
-		n *= (sfp[i].f)->value;
-	}
-	KNH_RETURN(ctx, sfp, new_Float(ctx, n));
+	KNH_RETURN_Float(ctx, sfp, ARG_float(sfp[0]) * ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[VARARGS|CONST] Float! Float.opDiv(Float! n) */
+/* @method[CONST] Float! Float.opDiv(Float! n) */
 
 METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_vargc_t ac = knh_sfp_argc(ctx, sfp);
-	size_t i; 
-	knh_float_t n = (sfp[0].f)->value;
-	for(i = 1; i < ac; i++) {
-		n /= (sfp[i].f)->value;
-	}
-	KNH_RETURN(ctx, sfp, new_Float(ctx, n));
+	KNH_RETURN_Float(ctx, sfp, ARG_float(sfp[0]) / ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] Float! Float.opMod(Float! n) */
-
-METHOD knh__Float_opMod(Ctx *ctx, knh_sfp_t *sfp)
-{
-#ifdef KNH_USING_MATH
-	knh_float_t a = (sfp[0].f)->value;
-	knh_float_t b = (sfp[1].f)->value;
-#if defined(KNH_FLOAT_TYPE__LONG_DOUBLE)
-	Float *v = new_Float(ctx, (knh_float_t)fmodl((long double)a, (long double)b));
-#elif defined(KNH_FLOAT_TYPE__FLOAT)
-	Float *v = new_Float(ctx, (knh_float_t)fmodf((float)a, (float)b));
-#else
-	Float *v = new_Float(ctx, (knh_float_t)fmod((double)a, (double)b));
-#endif
-	KNH_RETURN(ctx, sfp, v);
-#else
-	TODO_THROW(ctx);
-#endif
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method[CONST] Boolean! Float.opEq(Float! value) */
+/* @method[CONST|NULLBASE] Boolean! Float.opEq(Float value) */
 
 METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value == (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) == ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] Boolean! Float.opNeq(Float! value) */
+/* @method[CONST|NULLBASE] Boolean! Float.opNeq(Float value) */
 
 METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value != (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) != ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -200,12 +106,7 @@ METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value < (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) < ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -213,12 +114,7 @@ METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value <= (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) <= ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -226,12 +122,7 @@ METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value > (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) > ARG_float(sfp[1]));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -239,23 +130,15 @@ METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp)
 {
-	if((sfp[0].f)->value >= (sfp[1].f)->value) {
-		KNH_RETURN(ctx, sfp, KNH_TRUE);
-	}
-	else {
-		KNH_RETURN(ctx, sfp, KNH_FALSE);
-	}
+	KNH_RETURN_Boolean(ctx, sfp, ARG_float(sfp[0]) >= ARG_float(sfp[1]));
 }
 
-
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opNext() */
 
 METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp)
 {
-	Float *n = new_Float(ctx, ((sfp[0].f)->value)+1.0);
-	KNH_RETURN(ctx, sfp, n);
+	KNH_RETURN_Float(ctx, sfp, (ARG_float(sfp[0]))+1.0);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -264,25 +147,35 @@ METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp)
 {
-	Float *n = new_Float(ctx, ((sfp[0].f)->value) - 1.0);
-	KNH_RETURN(ctx, sfp, n);
+	KNH_RETURN_Float(ctx, sfp, (ARG_float(sfp[0]))-1.0);
 }
 
 /* ------------------------------------------------------------------------ */
-
-/* ------------------------------------------------------------------------ */
-/* @method Float Float.random() @ClassFunc */
+/* @method[STATIC] Float Float.random()  */
 
 METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp)
 {
-	Float *v = new_Float(ctx, ((knh_float_t)knh_rand()) / KNH_UINT_MAX);
-	KNH_RETURN(ctx, sfp, v);
+	KNH_RETURN_Float(ctx, sfp, ((knh_float_t)knh_rand()) / KNH_UINT_MAX);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method[NULLBASE|CONST] Int! Float.getSize() */
+
+METHOD knh__Float_getSize(Ctx *ctx, knh_sfp_t *sfp)
+{
+	if(IS_NULL(sfp[0].o)) {
+		KNH_RETURN_Int(ctx, sfp, 0);
+	}
+	else {
+		knh_uinteger_t n = (knh_uinteger_t)ARG_float(sfp[0]);
+		KNH_RETURN_Int(ctx, sfp, n);
+	}
 }
 
 /* ======================================================================== */
 /* [mapping] */
 
-/* @map[CONST] String Float */
+/* @map[CONST] String Float @Final */
 
 Float* knh_String_Float(Ctx *ctx, String *s, Mapper *mpr)
 {
@@ -304,7 +197,7 @@ String* knh_Float_String(Ctx *ctx, Float *o, Mapper *mpr)
 
 Float* knh_Int_Float(Ctx *ctx, Int *o, Mapper *mpr)
 {
-	return new_FloatX(ctx, DP(mpr)->tcid, (knh_float_t)knh_Int_value((o)));
+	return new_FloatX(ctx, DP(mpr)->tcid, (knh_float_t)(o)->value);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -312,7 +205,7 @@ Float* knh_Int_Float(Ctx *ctx, Int *o, Mapper *mpr)
 
 Int* knh_Float_Int(Ctx *ctx, Float *o, Mapper *mpr)
 {
-	return new_IntX(ctx, DP(mpr)->tcid, knh_Float_toint(o));
+	return new_IntX(ctx, DP(mpr)->tcid, (knh_integer_t)(o)->value);
 }
 
 /* ======================================================================== */
@@ -321,15 +214,15 @@ Int* knh_Float_Int(Ctx *ctx, Float *o, Mapper *mpr)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%s(OutputStream w, String m) */
 
-void knh_Float__s(Ctx *ctx, Float *b, OutputStream *w, String *m)
+void knh_Float__s(Ctx *ctx, Float *o, OutputStream *w, String *m)
 {
-	knh_write__ffmt(ctx, w, KNH_FLOAT_FMT, b->value);
+	knh_write__ffmt(ctx, w, KNH_FLOAT_FMT, o->value);
 }
 
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%d(OutputStream w, String m) */
 
-void knh_Float__d(Ctx *ctx, Int *o, OutputStream *w, String *m)
+void knh_Float__d(Ctx *ctx, Float *o, OutputStream *w, String *m)
 {
 	if(IS_String(m)) {
 		char fmt[40], buf[256];
@@ -345,7 +238,7 @@ void knh_Float__d(Ctx *ctx, Int *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%f(OutputStream w, String m) */
 
-void knh_Float__f(Ctx *ctx, Int *o, OutputStream *w, String *m)
+void knh_Float__f(Ctx *ctx, Float *o, OutputStream *w, String *m)
 {
 	if(IS_String(m)) {
 		char fmt[40], buf[256];
@@ -361,11 +254,11 @@ void knh_Float__f(Ctx *ctx, Int *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%k(OutputStream w, String m) */
 
-void knh_Float__k(Ctx *ctx, Float *b, OutputStream *w, String *m)
+void knh_Float__k(Ctx *ctx, Float *o, OutputStream *w, String *m)
 {
-	FloatUnit *u = (FloatUnit*)knh_tClass[b->h.cid].cspec;
+	FloatUnit *u = (FloatUnit*)knh_tClass[o->h.cid].cspec;
 	KNH_ASSERT(IS_FloatUnit(u));
-	knh_write__ffmt(ctx, w, DP(u)->FMT, b->value);
+	knh_write__ffmt(ctx, w, DP(u)->FMT, o->value);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -391,11 +284,11 @@ void knh_Float__bits(Ctx *ctx, Float *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%dump(OutputStream w, String m) */
 
-void knh_Float__dump(Ctx *ctx, Float *b, OutputStream *w, String *m)
+void knh_Float__dump(Ctx *ctx, Float *o, OutputStream *w, String *m)
 {
-	FloatUnit *u = (FloatUnit*)knh_tClass[b->h.cid].cspec;
+	FloatUnit *u = (FloatUnit*)knh_tClass[o->h.cid].cspec;
 	KNH_ASSERT(IS_FloatUnit(u));
-	knh_write__ffmt(ctx, w, DP(u)->FMT, b->value);
+	knh_write__ffmt(ctx, w, DP(u)->FMT, o->value);
 	knh_bytes_t tag = knh_String_tobytes(DP(u)->spec.tag);
 	if(tag.len > 0) {
 		knh_putc(ctx, w, '[');
@@ -406,16 +299,6 @@ void knh_Float__dump(Ctx *ctx, Float *b, OutputStream *w, String *m)
 
 /* ------------------------------------------------------------------------ */
 
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [mapping] */
-
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [movabletext] */
-
-/* ------------------------------------------------------------------------ */
-
 #ifdef __cplusplus
 }
 #endif
