@@ -44,7 +44,7 @@ extern "C" {
 /* ======================================================================== */
 /* [constructors] */
 
-Int* new_IntX0(Ctx *ctx, knh_class_t cid, knh_int_t value)
+Int* new_IntX0(Ctx *ctx, knh_class_t cid, knh_integer_t value)
 {
 	knh_Int_t *b = (knh_Int_t*)new_PObject0(ctx, FLAG_Int, CLASS_Int, cid);
 	b->value = value;
@@ -53,7 +53,7 @@ Int* new_IntX0(Ctx *ctx, knh_class_t cid, knh_int_t value)
 
 /* ------------------------------------------------------------------------ */
 
-Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_int_t value)
+Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_integer_t value)
 {
 	DEBUG_ASSERT_cid(cid);
 	{
@@ -84,7 +84,7 @@ Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_int_t value)
 
 Int *new_IntX__b(Ctx *ctx, knh_class_t cid, knh_bytes_t t)
 {
-	knh_uint_t n = 0, prev = 0, base = 10;
+	knh_uinteger_t n = 0, prev = 0, base = 10;
 	size_t i = 0;
 
 	if(t.len > 1) {
@@ -128,10 +128,10 @@ Int *new_IntX__b(Ctx *ctx, knh_class_t cid, knh_bytes_t t)
 		}
 	}
 	if(t.buf[0] == '-') {
-		return new_IntX(ctx, cid, (-((knh_int_t)n)));
+		return new_IntX(ctx, cid, (-((knh_integer_t)n)));
 	}
 	else {
-		return new_IntX(ctx, cid, (knh_int_t)n);
+		return new_IntX(ctx, cid, (knh_integer_t)n);
 	}
 }
 
@@ -139,9 +139,9 @@ Int *new_IntX__b(Ctx *ctx, knh_class_t cid, knh_bytes_t t)
 
 Object *knh_Int_cspec(Ctx *ctx)
 {
-	knh_IntUnit_t *u = new_IntUnit(ctx, 0, CLASS_Int, TS_EMPTY, TS_EMPTY, KNH_INT_MIN, KNH_INT_MAX, 0, KNH_TINT_MIN, KNH_TINT_MAX);
-	KNH_TCONST__T(ctx, "konoha.Int.MAX", (Object*)new_IntX0(ctx, CLASS_Int, KNH_INT_MAX));
-	KNH_TCONST__T(ctx, "konoha.Int.MIN", (Object*)new_IntX0(ctx, CLASS_Int, KNH_INT_MIN));
+	knh_IntUnit_t *u = new_IntUnit(ctx, 0, CLASS_Int, TS_EMPTY, TS_EMPTY, KNH_INTEGER_MIN, KNH_INTEGER_MAX, 0, KNH_TINT_MIN, KNH_TINT_MAX);
+	KNH_TCONST__T(ctx, "konoha.Int.MAX", (Object*)new_IntX0(ctx, CLASS_Int, KNH_INTEGER_MAX));
+	KNH_TCONST__T(ctx, "konoha.Int.MIN", (Object*)new_IntX0(ctx, CLASS_Int, KNH_INTEGER_MIN));
 	return (Object*)u;
 }
 
@@ -227,7 +227,7 @@ knh_uint_t knh_uint_min(knh_uint_t a, knh_uint_t b)
 
 /* ======================================================================== */
 
-knh_int_t knh_IntNULL_toint(Int *v)
+knh_integer_t knh_IntNULL_toint(Int *v)
 {
 	if(IS_NULL(v)) {
 		return 0;
