@@ -236,6 +236,7 @@ knh_hcode_t knh_String_hashCode(String *o)
 
 int knh_String_compareTo(String *o, String *o2)
 {
+	DBG2_P("compareTo: %s, %s", knh_String_tochar(o), knh_String_tochar(o2));
 	if(o->h.cid == CLASS_String || o2->h.cid == CLASS_String) {
 		size_t i, max = knh_uint_min(o->size, o2->size);
 		for(i = 0; i < max; i++) {
@@ -246,10 +247,12 @@ int knh_String_compareTo(String *o, String *o2)
 	}
 	else {
 		if(o->h.cid == o2->h.cid) {
+			DBG2_P("both, Same");
 			StringUnit *u = (StringUnit*)knh_tClass[o->h.cid].cspec;
 			KNH_ASSERT(IS_StringUnit(u));
 			return DP(u)->fcmp(u, knh_String_tobytes(o), knh_String_tobytes(o2));
 		}
+		DBG2_P("anything");
 		return (int)(o - o2);
 	}
 }
