@@ -74,6 +74,14 @@ static
 knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
 {
 	size_t i, j;
+	//TODO: handle, when delim is NULL. ""
+	if(delim.len > base.len) {
+		char buf[80];
+		//TODO: Exception!!!
+		knh_snprintf(buf, sizeof(buf), "Arg String is Invalid size: %d (> %d)", (int)delim.len, (int)base.len);
+		DBG2_P("%s", buf);
+		return -1;
+	}
 	for (i = 0; i <= base.len - delim.len; i++) {
 		j = 0;
 		while ((j < delim.len) && (base.buf[i+j] == delim.buf[j])) {
@@ -86,9 +94,9 @@ knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
 
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! String.indexOf(String! s) */
-
 METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 {
+
 	KNH_RETURN(ctx, sfp, new_Int(ctx, knh_bytes_indexOf(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s))));
 }
 
@@ -112,9 +120,9 @@ METHOD knh__String_getSize(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST|NULLBASE] String! String.opAdd:2(Any v) */
+/* @method[CONST|NULLBASE] String! String.opAdd(Any v) */
 
-METHOD knh__String_opAdd__2(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_wbuf_t cb = knh_Context_wbuf(ctx);
 	knh_format(ctx, cb.w, METHODN__s, sfp[0].o, KNH_NULL);
@@ -123,9 +131,9 @@ METHOD knh__String_opAdd__2(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[VARARGS|STATIC|NULLBASE] String! String.opAdd(Any v) */
+/* @method[VARARGS|STATIC|NULLBASE] String! String.concat(Any v) */
 
-METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_sfp_t *v = sfp + 1;
 	knh_vargc_t ac = knh_sfp_argc(ctx, v);
@@ -139,9 +147,9 @@ METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] String! String.opSub:2(String! t) */
+/* @method[CONST] String! String.opSub(String! t) */
 
-METHOD knh__String_opSub__2(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	knh_bytes_t t = knh_String_tobytes(sfp[1].s);
@@ -236,14 +244,6 @@ METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method[CONST] String! String.opMul:2(Int! n) */
-
-METHOD knh__String_opMul__2(Ctx *ctx, knh_sfp_t *sfp)
-{
-	knh__String_opMul(ctx, sfp);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] String! String.opFmt(Any v) */
 
@@ -323,9 +323,9 @@ METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
 
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST|NULLBASE] String! String.opDiv:2(String v) */
+/* @method[CONST|NULLBASE] String! String.opDiv(String v) */
 
-METHOD knh__String_opDiv__2(Ctx *ctx, knh_sfp_t *sfp)
+METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(!IS_bString(sfp[0].o)) {
 		KNH_RETURN(ctx, sfp, TS_EMPTY);
@@ -348,14 +348,6 @@ METHOD knh__String_opDiv__2(Ctx *ctx, knh_sfp_t *sfp)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method[CONST|NULLBASE] String! String.opDiv(String v) */
-
-METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp)
-{
-	knh__String_opDiv__2(ctx, sfp);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] String! String.opMod(String v) */
 
@@ -373,13 +365,12 @@ METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp)
 		}
 		else {
 			base.buf = base.buf + (index + delim.len);
-			base.len = (base.len - index + delim.len) - 1;
+			base.len = (base.len - (index+1) + delim.len) - 1;	//index+1 : because index is just an array index.
 			KNH_RETURN(ctx, sfp, new_String(ctx, base, sfp[0].s));
 		}
 	}
 }
 
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! String.opHas(String! s) */
 
@@ -419,7 +410,7 @@ METHOD knh__String_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 			KNH_RETURN(ctx, sfp, new_String(ctx, knh_bytes_last(base, offset), sfp[0].s));
 		}
 		else {
-			knh_bytes_t sub = knh_bytes_offlen(base, offset, ARG_int(sfp[2]));
+			knh_bytes_t sub = knh_bytes_offlen(base, offset, knh_array_index(ctx, ARG_int(sfp[2]), base.len - offset ));
 			KNH_RETURN(ctx, sfp, new_String(ctx, sub, sfp[0].s));
 		}
 	}
