@@ -661,15 +661,20 @@ void KNH_ASM_MOV(Ctx *ctx, Compiler *cpr, Token* n, Term *v)
 
 void knh_StmtLET_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level)
 {
-	knh_Stmt_terms_cmpl(ctx, stmt, LET_lvalue, cpr, ns, CLASS_Any, 0);
-	KNH_ASSERT(IS_Token(DP(stmt)->tokens[LET_lvalue]));
-	reqt = DP(DP(stmt)->tokens[LET_lvalue])->type;
-	//knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, TYPE_UNMASK_NN(reqt));
-	knh_Stmt_terms_cmpl(ctx, stmt, LET_rvalue, cpr, ns, reqt, 0);
-	KNH_ASM_MOV(ctx, cpr, DP(stmt)->tokens[LET_lvalue], DP(stmt)->terms[LET_rvalue]);
-
-	if(!knh_Stmt_isStatement(stmt)) {
-		knh_Stmt_terms_cmplpush(ctx, stmt, LET_lvalue, cpr, ns, reqt, level);
+	if(knh_Stmt_isStatement(stmt)) {
+		knh_Stmt_terms_cmpl(ctx, stmt, LET_lvalue, cpr, ns, CLASS_Any, 0);
+		KNH_ASSERT(IS_Token(DP(stmt)->tokens[LET_lvalue]));
+		reqt = DP(DP(stmt)->tokens[LET_lvalue])->type;
+		knh_Stmt_terms_cmpl(ctx, stmt, LET_rvalue, cpr, ns, reqt, 0);
+		KNH_ASM_MOV(ctx, cpr, DP(stmt)->tokens[LET_lvalue], DP(stmt)->terms[LET_rvalue]);
+	}
+	else {
+		knh_Stmt_terms_cmpl(ctx, stmt, LET_lvalue, cpr, ns, CLASS_Any, 0);
+		KNH_ASSERT(IS_Token(DP(stmt)->tokens[LET_lvalue]));
+		reqt = DP(DP(stmt)->tokens[LET_lvalue])->type;
+		knh_Stmt_terms_cmpl(ctx, stmt, LET_rvalue, cpr, ns, reqt, level);
+		KNH_ASM_MOV(ctx, cpr, DP(stmt)->tokens[LET_lvalue], DP(stmt)->terms[LET_rvalue]);
+		//knh_Stmt_terms_cmplpush(ctx, stmt, LET_lvalue, cpr, ns, reqt, level);
 	}
 }
 
