@@ -207,10 +207,11 @@ Term *knh_StmtPARAMS_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns,
 	size_t i, size = DP(stmt)->size;
 	knh_class_t self_cid = TYPE_UNMASK_NN(btype);
 	knh_type_t rtype = knh_pmztype_totype(ctx, knh_Method_rtype(mtd), self_cid);
-	if(TYPE_ISNULLABLE(btype) && !knh_Method_isNullBase(mtd)) {
-		//DEBUG3("Null OBJECT Pattern!!");
-		rtype = TYPE_UNMASK_NN(rtype);
-	}
+
+//	if(TYPE_ISNULLABLE(btype) && !knh_Method_isNullBase(mtd)) {
+//		//DEBUG3("Null OBJECT Pattern!!");
+//		rtype = TYPE_UNMASK_NN(rtype);
+//	}
 
 	for(i = 0; i < knh_Method_psize(mtd); i++) {
 		knh_type_t reqt = knh_pmztype_totype(ctx, knh_Method_ptype(mtd, i), self_cid);
@@ -493,8 +494,6 @@ Term *knh_StmtCALL_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, kn
 					knh_Token_perror(ctx, DP(stmt)->tokens[1], KMSG_UCLASSN);
 					return knh_Stmt_foundTypeError(ctx, stmt, cpr);
 				}
-//				knh_Token_perrata(ctx, tk_base, "null");
-//				return new_TokenCONST(ctx, tk_base, KNH_NULL);      /* CONST  */
 			}
 		}
 	}
@@ -527,39 +526,73 @@ Term *knh_StmtCALL_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, kn
 }
 
 /* ------------------------------------------------------------------------ */
+
+static
+void knh_Stmt_toBinaryOperator(Ctx *ctx, Stmt *stmt)
+{
+	size_t i;
+	while(DP(stmt)->size > 3) {
+		Stmt *newstmt = new_Stmt(ctx, 0, STT_OP);
+		knh_Stmt_add(ctx, newstmt, DP(stmt)->terms[0]);
+		knh_Stmt_add(ctx, newstmt, DP(stmt)->terms[1]);
+		knh_Stmt_add(ctx, newstmt, DP(stmt)->terms[2]);
+		KNH_SETv(ctx, DP(stmt)->terms[1], newstmt);
+		DP(stmt)->size -= 1;
+		for(i = 2; i < DP(stmt)->size; i++) {
+			KNH_SETv(ctx, DP(stmt)->terms[i], DP(stmt)->terms[i+1]);
+		}
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+knh_class_t knh_Stmt_checkStringAdd(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_class_t reqc)
+{
+	size_t i;
+	DEBUG_ASSERT_cid(reqc);
+	reqc = knh_tClass[reqc].bcid;
+
+	for(i = 1; i < DP(stmt)->size; i++) {
+		knh_Stmt_terms_typing(ctx, stmt, i, cpr, ns, CLASS_Any);
+		if(reqc == CLASS_String) continue;
+		if(knh_Term_get_bcid(DP(stmt)->terms[i]) == CLASS_String) {
+			reqc = CLASS_String;
+		}
+	}
+	if(reqc != CLASS_String) {
+		knh_Stmt_toBinaryOperator(ctx, stmt);
+	}
+	return reqc;
+}
+
 /* ------------------------------------------------------------------------ */
 
 static
 knh_class_t knh_Stmt_infer_opAdd(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_class_t reqc)
 {
-	int i, has_Int = 0, has_Int64 = 0;
-	knh_class_t bcid;
+	KNH_ASSERT(DP(stmt)->size == 3);
 	DEBUG_ASSERT_cid(reqc);
 	reqc = knh_tClass[reqc].bcid;
-	for(i = 1; i < DP(stmt)->size; i++) {
-		if(reqc == CLASS_String) {
-			knh_Stmt_terms_typing(ctx, stmt, i, cpr, ns, CLASS_Any);
-			continue;
-		}
-		else {
-			knh_Stmt_terms_typing(ctx, stmt, i, cpr, ns, CLASS_Any);
-			bcid = knh_Term_get_bcid(DP(stmt)->terms[i]);
-			//DEBUG3("OP[+%d] %s", i, CLASSN(bcid));
-			if(bcid == CLASS_String) { reqc = bcid; continue;}
-			if(bcid == CLASS_Any) { reqc = bcid; continue; }
-			if(bcid == CLASS_Any) continue;
-			if(bcid == CLASS_Int) has_Int = 1;
-			if(bcid == CLASS_Int64) has_Int64 = 1;
-			if(bcid == CLASS_Float) { reqc = bcid;}
-			if(reqc == CLASS_Float) continue;
-			if(bcid == CLASS_Int64) { reqc = bcid;}
-			if(reqc == CLASS_Int64) continue;
-			if(bcid == CLASS_Int) { reqc = bcid; }
-		}
+	knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, CLASS_Any);
+	knh_Stmt_terms_typing(ctx, stmt, 2, cpr, ns, CLASS_Any);
+	knh_class_t cid1 = knh_Term_get_cid(DP(stmt)->terms[1]);
+	knh_class_t cid2 = knh_Term_get_cid(DP(stmt)->terms[2]);
+	if(cid1 == cid2) return cid1;
+	if(cid1 == CLASS_Any || cid2 == CLASS_Any) return CLASS_Any;
+
+	knh_class_t bcid1 = knh_tClass[cid1].bcid;
+	knh_class_t bcid2 = knh_tClass[cid2].bcid;
+
+	if(bcid1 == bcid2) return bcid1;
+
+	if(bcid1 == CLASS_Float && bcid2 == CLASS_Int) {
+		return CLASS_Number;
 	}
-	if(reqc == CLASS_Float && (has_Int || has_Int64)) return CLASS_Number;
-	if(reqc == CLASS_Int64 && has_Int) return CLASS_Number;
-	return reqc;
+	if(bcid2 == CLASS_Float && bcid1 == CLASS_Int) {
+		return CLASS_Number;
+	}
+	return cid1;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -567,30 +600,36 @@ knh_class_t knh_Stmt_infer_opAdd(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace
 static
 knh_class_t knh_Stmt_infer_opEq(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns)
 {
-	knh_class_t bcid, bcid2;
+	KNH_ASSERT(DP(stmt)->size == 3);
 	knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, CLASS_Any);
-	bcid = knh_Term_get_bcid(DP(stmt)->terms[1]);
 	knh_Stmt_terms_typing(ctx, stmt, 2, cpr, ns, CLASS_Any);
-	bcid2 = knh_Term_get_bcid(DP(stmt)->terms[2]);
-	if(bcid == bcid2) return bcid;
-	if(bcid == CLASS_Any || bcid2 == CLASS_Any) return CLASS_Object;
 
-	if(bcid == CLASS_Float) {
-		if(bcid2 == CLASS_Int || bcid2 == CLASS_Int64) return CLASS_Number;
+	knh_class_t cid1 = knh_Term_get_cid(DP(stmt)->terms[1]);
+	knh_class_t cid2 = knh_Term_get_cid(DP(stmt)->terms[2]);
+
+	if(cid1 == cid2) return cid1;
+	if(cid1 == CLASS_Any || cid2 == CLASS_Any) return CLASS_Any;
+
+	knh_class_t bcid1 = knh_tClass[cid1].bcid;
+	knh_class_t bcid2 = knh_tClass[cid2].bcid;
+
+	if(bcid1 == cid2) return bcid1;
+	if(bcid2 == cid1) return bcid2;
+
+	if(cid1 == CLASS_Float && bcid2 == CLASS_Int) {
+		return CLASS_Number;
 	}
-	if(bcid2 == CLASS_Float) {
-		if(bcid == CLASS_Int || bcid == CLASS_Int64) return CLASS_Number;
+	if(cid2 == CLASS_Float && bcid1 == CLASS_Int) {
+		return CLASS_Number;
 	}
 
-	if(bcid == CLASS_Int64) {
-		if(bcid2 == CLASS_Int) return CLASS_Number;
+	if(bcid1 == CLASS_Float && cid2 == CLASS_Int) {
+		return CLASS_Number;
 	}
-
-	if(bcid2 == CLASS_Int64) {
-		if(bcid == CLASS_Int) return CLASS_Number;
+	if(bcid2 == CLASS_Float && cid1 == CLASS_Int) {
+		return CLASS_Number;
 	}
-	DEBUG3("CANNOT COMPARE %s %s", CLASSN(bcid), CLASSN(bcid2));
-	return CLASS_Object;
+	return CLASS_unknown;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -602,7 +641,7 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	Token *optk = DP(stmt)->tokens[0];
 	knh_methodn_t mn = knh_token_tomethodn(SP(optk)->tt);
 	DEBUG3_ASSERT(mn != METHODN_NONAME);
-	knh_class_t   mtd_cid = CLASS_unknown;
+	knh_class_t mtd_cid = CLASS_unknown;
 	int typechecked = 0;
 
 	switch(mn) {
@@ -612,54 +651,21 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 			knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, reqc);
 			return DP(stmt)->terms[1];
 		}
-		else if(opsize == 2) {
-			mn = METHODN_opAdd__2;
+		mtd_cid = knh_Stmt_checkStringAdd(ctx, stmt, cpr, ns, reqc);
+		if(mtd_cid == CLASS_String) {
+			if(opsize > 2) {
+				mn = METHODN_concat;
+			}
+			typechecked = 1;
+			break;
 		}
-		mtd_cid = knh_Stmt_infer_opAdd(ctx, stmt, cpr, ns, reqc);;
-		typechecked = 1;
 	}
-	break;
 
 	case METHODN_opSub:
-	{
-		if(opsize == 1) {
-			knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, reqc);
-			mn = METHODN_opNeg;
-		}
-		else if(opsize == 2) {
-			mn = METHODN_opSub__2;
-		}
-		mtd_cid = knh_Stmt_infer_opAdd(ctx, stmt, cpr, ns, reqc);;
-		typechecked = 1;
-	}
-	break;
-
 	case METHODN_opMul:
-	{
-		if(opsize == 1) {
-			knh_Compiler_perror(ctx, cpr, KMSG_EOP2, knh_token_tochar(SP(optk)->tt));
-			return knh_Stmt_foundTypeError(ctx, stmt, cpr);
-		}
-		else if(opsize == 2) {
-			mn = METHODN_opMul__2;
-		}
-		mtd_cid = knh_Stmt_infer_opAdd(ctx, stmt, cpr, ns, reqc);;
-		typechecked = 1;
-	}
-	break;
-
 	case METHODN_opDiv:
-	{
-		if(opsize == 1) {
-			knh_Compiler_perror(ctx, cpr, KMSG_EOP2, knh_token_tochar(SP(optk)->tt));
-			return knh_Stmt_foundTypeError(ctx, stmt, cpr);
-		}
-		else if(opsize == 2) {
-			mn = METHODN_opDiv__2;
-		}
-		mtd_cid = knh_Stmt_infer_opAdd(ctx, stmt, cpr, ns, reqc);;
-		typechecked = 1;
-	}
+		mtd_cid = knh_Stmt_infer_opAdd(ctx, stmt, cpr, ns, reqc);
+		//typechecked = 1;
 	break;
 
 	case METHODN_opLor:
@@ -677,6 +683,8 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	break;
 
 	case METHODN_opEq: case METHODN_opNeq:
+	{
+		mtd_cid = knh_Stmt_infer_opEq(ctx, stmt, cpr, ns);
 		if(knh_StmtTERMs_isNULL(stmt, 2)) {
 			Term *temp = DP(stmt)->terms[1];
 			DP(stmt)->terms[1] = DP(stmt)->terms[2];
@@ -686,23 +694,40 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 			break;
 		}
 
+		//mtd_cid = knh_Stmt_infer_opEq(ctx, stmt, cpr, ns);
+		if(mtd_cid == CLASS_unknown) {
+			knh_token_t tt = SP(optk)->tt;
+			char bufcc[CLASSNAME_BUFSIZ];
+			knh_snprintf(bufcc, sizeof(bufcc), "%s %s %s",
+					CTXCLASSN(knh_Term_get_cid(DP(stmt)->terms[1])),
+					knh_token_tochar(tt),
+					CTXCLASSN(knh_Term_get_cid(DP(stmt)->terms[2])));
+			knh_Compiler_perror(ctx, cpr, KMSG_WOPCMP, bufcc);
+			if(mn == METHODN_opEq) {
+				knh_Token_perrata(ctx, optk, "false");
+				return TM(new_TokenCONST(ctx, FL(optk), KNH_FALSE)); /* CONST */
+			}
+			else { /* mn == METHODN_opNeq */
+				knh_Token_perrata(ctx, optk, "true");
+				return TM(new_TokenCONST(ctx, FL(optk), KNH_TRUE)); /* CONST */
+			}
+		}
+	}
+	typechecked = 1;
+	break;
+
 	case METHODN_opGt: case METHODN_opGte:
 	case METHODN_opLt: case METHODN_opLte:
 	{
-		if(opsize != 2) {
-			knh_Compiler_perror(ctx, cpr, KMSG_EOP2, knh_token_tochar(SP(optk)->tt));
-			return knh_Stmt_foundTypeError(ctx, stmt, cpr);
-		}
-
 		mtd_cid = knh_Stmt_infer_opEq(ctx, stmt, cpr, ns);
-
-		if(mtd_cid == CLASS_Object) {
+		if(mtd_cid == CLASS_unknown) {
+			knh_token_t tt = SP(optk)->tt;
 			char bufcc[CLASSNAME_BUFSIZ];
 			knh_snprintf(bufcc, sizeof(bufcc), "%s %s %s",
-					CLASSN(knh_Term_get_cid(DP(stmt)->terms[1])),
-					knh_token_tochar(SP(optk)->tt),
-					CLASSN(knh_Term_get_cid(DP(stmt)->terms[2])));
-			knh_Compiler_perror(ctx, cpr, KMSG_EOPCMP, bufcc);
+					CTXCLASSN(knh_Term_get_cid(DP(stmt)->terms[1])),
+					knh_token_tochar(tt),
+					CTXCLASSN(knh_Term_get_cid(DP(stmt)->terms[2])));
+			knh_Compiler_perror(ctx, cpr, KMSG_WOPCMP, bufcc);
 			knh_Token_perrata(ctx, optk, "false");
 			return TM(new_TokenCONST(ctx, FL(optk), KNH_FALSE)); /* CONST */
 		}
@@ -711,22 +736,19 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	break;
 
 	case METHODN_opHas:
-		if(opsize == 2) {
-			Term *temp = DP(stmt)->terms[1];
-			DP(stmt)->terms[1] = DP(stmt)->terms[2];
-			DP(stmt)->terms[2] = temp;
-			knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, CLASS_Any);
-			mtd_cid = TYPE_UNMASK_NN(knh_Term_get_cid(DP(stmt)->terms[1]));
-			typechecked = 0;
-		}
-		else {
-			knh_Compiler_perror(ctx, cpr, KMSG_UOP2, knh_token_tochar(SP(optk)->tt));
-			return knh_Stmt_foundTypeError(ctx, stmt, cpr);
-		}
+	{
+		Term *temp = DP(stmt)->terms[1];
+		DP(stmt)->terms[1] = DP(stmt)->terms[2];
+		DP(stmt)->terms[2] = temp;
+		knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, CLASS_Any);
+		mtd_cid = TYPE_UNMASK_NN(knh_Term_get_cid(DP(stmt)->terms[1]));
+	}
+	typechecked = 0;
+	break;
 
 	default:
 		knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, CLASS_Any);
-		mtd_cid = TYPE_UNMASK_NN(knh_Term_get_cid(DP(stmt)->terms[1]));
+		mtd_cid = knh_Term_get_cid(DP(stmt)->terms[1]);
 		typechecked = 0;
 	}
 
@@ -734,25 +756,23 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 	{
 		Method *mtd = knh_Class_getMethod(ctx, mtd_cid, mn);
 		if(IS_NULL(mtd)) {
-			//DEBUG3("mtd_cid=%s", CLASSN(mtd_cid));
 			knh_Compiler_perror(ctx, cpr, KMSG_UOP, knh_token_tochar(SP(optk)->tt));
 			return knh_Stmt_foundTypeError(ctx, stmt, cpr);
 		}
-		//DEBUG3("typechecked=%d",typechecked);
 		if(typechecked == 0) {
 			knh_Stmt_terms_typing(ctx, stmt, 1, cpr, ns, mtd_cid);
-			return knh_StmtPARAMS_typing(ctx, stmt, cpr, ns, mtd_cid, mtd);
+			return knh_StmtPARAMS_typing(ctx, stmt, cpr, ns, knh_Term_get_type(ctx, cpr, DP(stmt)->terms[1]), mtd);
 		}
 		else {
 			knh_type_t rtype = knh_pmztype_totype(ctx, knh_Method_rtype(mtd), mtd_cid);
 			if(knh_StmtCALL_isCONST(stmt, mtd)) {
 				return knh_StmtCALL_toCONST(ctx, stmt, mtd);
 			}
+//			fprintf(stderr, "********** rtype =%s%s,%s%s ***********\n", TYPEQN(knh_Method_rtype(mtd)), TYPEQN(rtype));
 			knh_Token_setMETHOD(ctx, DP(stmt)->tokens[0], mn, mtd, rtype);
 			knh_Stmt_setType(stmt, rtype);
 		}
 	}
-	//DEBUG3("rtype=%s%s", TYPEQN(DP(stmt)->type));
 	return TM(stmt);
 }
 
@@ -786,7 +806,6 @@ Term *knh_StmtNEW_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh
 		DEBUG_ASSERT_cid(reqc);
 		if(knh_tClass[reqc].bcid == CLASS_Array) {
 			mtd_cid = reqc;
-//			mtd_cid = knh_Compiler_typeinfer(ctx, cpr, mtd_cid, "[]");
 		}
 		else if(reqc == CLASS_Any && mn == METHODN_new__init && DP(stmt)->size > 2) {
 			knh_Stmt_terms_typing(ctx, stmt, 2, cpr, ns, CLASS_Any);
@@ -802,7 +821,6 @@ Term *knh_StmtNEW_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh
 				}
 				if(icid != CLASS_Any) {
 					mtd_cid = knh_class_Array(ctx, icid);
-//					knh_notice_TypeInf(ctx, SP(stmt)->fileid, SP(stmt)->line, "[]", mtd_cid);
 				}
 			}
 		}
@@ -1278,13 +1296,10 @@ int knh_class_isImplictCastingTo(Ctx *ctx, knh_class_t varc, knh_class_t reqc)
 {
 	if(varc == CLASS_Any) return 1;
 	if(varc == CLASS_Float) {
-		return (reqc == CLASS_Int || reqc == CLASS_Int64);
+		return (reqc == CLASS_Int);
 	}
 	if(varc == CLASS_Int) {
-		return (reqc == CLASS_Float || reqc == CLASS_Int64);
-	}
-	if(varc == CLASS_Int64) {
-		return (reqc == CLASS_Int || reqc == CLASS_Float);
+		return (reqc == CLASS_Float);
 	}
 	return 0;
 }
@@ -1301,6 +1316,7 @@ void knh_Stmt_terms_cmpl_(Ctx *ctx, Stmt *stmt, int n, Compiler *cpr, NameSpace
 	if(!knh_Term_isTyped(DP(stmt)->terms[n])) {
 		knh_Stmt_terms_typing(ctx, stmt, n, cpr, ns, TYPE_UNMASK_NN(reqt));
 	}
+
 	{
 		Term *tm = DP(stmt)->terms[n];
 		knh_class_t reqc = TYPE_UNMASK_NN(reqt);  /*tcid*/
@@ -1312,10 +1328,6 @@ void knh_Stmt_terms_cmpl_(Ctx *ctx, Stmt *stmt, int n, Compiler *cpr, NameSpace
 			if(SP(stmt)->stt == STT_ERR) return;
 		}
 
-//		if(IS_Token(tm) && SP((Token*)tm)->tt == TT_SYSCONST) {
-//			push = 1; /* always push */
-//		}
-
 		if(vart == TYPE_void) {
 			knh_Stmt_perrorEVOID(ctx, stmt, n);
 			KNH_ASM_THROWERR__S(ctx, cpr, TS_TYPEERR);
@@ -1492,6 +1504,7 @@ void knh_StmtOP_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 	DEBUG3_ASSERT(SP(mtdtk)->tt == TT_MTDMPR);
 	Method *mtd = DP(mtdtk)->mtd;
 	DEBUG3_ASSERT(IS_Method(mtd));
+
 	SP(stmt)->stt = STT_CALL; /* for error message  */
 	knh_type_t btype = knh_Term_get_type(ctx, cpr, DP(stmt)->terms[1]);
 	knh_class_t base_cid = TYPE_UNMASK_NN(btype);
@@ -1506,6 +1519,7 @@ void knh_StmtOP_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_typ
 		knh_Stmt_terms_cmplpush(ctx, stmt, i, cpr, ns, reqt, level + i);
 		if(SP(stmt)->stt == STT_ERR) { return ;}
 	}
+
 	if(TYPE_ISNOTNULL(btype) || knh_Method_isNullBase(mtd)) {
 		KNH_ASM_SCALL(ctx, cpr, DP(stmt)->size - 1);
 	}
