@@ -291,10 +291,10 @@ void knh_Token_constCMETHODN(Ctx *ctx, Token *o, NameSpace *ns)
 /* [NUM] */
 
 static
-knh_int_t knh_Token_toint(Ctx *ctx, Token *o)
+knh_int_t knh_Token_tointeger(Ctx *ctx, Token *o)
 {
 	knh_bytes_t t = knh_Token_tobytes(o);
-	knh_uint_t n = 0, prev = 0, base = 10;
+	knh_uinteger_t n = 0, prev = 0, base = 10;
 	size_t i = 0;
 
 	if(t.len > 1) {
@@ -336,60 +336,8 @@ knh_int_t knh_Token_toint(Ctx *ctx, Token *o)
 			return 0;
 		}
 	}
-	if(t.buf[0] == '-') return -((knh_int_t)n);
-	return (knh_int_t)n;
-}
-
-/* ------------------------------------------------------------------------ */
-
-static
-knh_int64_t knh_Token_toint64(Ctx *ctx, Token *o)
-{
-	knh_bytes_t t = knh_Token_tobytes(o);
-	knh_int64_t n = 0, prev = 0, base = 10;
-	size_t i = 0;
-
-	if(t.len > 1) {
-		if(t.buf[0] == '0') {
-			if(t.buf[1] == 'x') {
-				base = 16; i = 2;
-			}
-			else if(t.buf[1] == 'b') {
-				base = 2;  i = 2;
-			}
-		}else if(t.buf[0] == '-') {
-			base = 10; i = 1;
-		}
-	}
-
-	for(;i < t.len; i++) {
-		int c = t.buf[i];
-		if('0' <= c && c <= '9') {
-			prev = n;
-			n = n * base + (c - '0');
-		}else if(base == 16) {
-			if('A' <= c && c <= 'F') {
-				prev = n;
-				n = n * 16 + (10 + c - 'A');
-			}else if('a' <= c && c <= 'f') {
-				prev = n;
-				n = n * 16 + (10 + c - 'a');
-			}else {
-				break;
-			}
-		}else if(c == '_') {
-			continue;
-		}else {
-			break;
-		}
-		if(!(n >= prev)) {
-			knh_Token_perror(ctx, o, KMSG_INT64OVERFLOW);
-			knh_Token_perrata(ctx, o, "0L");
-			return 0;
-		}
-	}
-	if(t.buf[0] == '-') return -((knh_int64_t)n);
-	return (knh_int64_t)n;
+	if(t.buf[0] == '-') return -((knh_integer_t)n);
+	return (knh_integer_t)n;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -399,50 +347,63 @@ knh_float_t knh_Token_tofloat(Ctx *ctx, Token *o)
 {
 	knh_bytes_t t = knh_Token_tobytes(o);
 	if(t.buf[0] == '0' && (t.buf[1] == 'x' || t.buf[1] == 'b')) {
-		knh_int64_t n = knh_Token_toint64(ctx, o);
+		knh_integer_t n = knh_Token_tointeger(ctx, o);
 		return (knh_float_t)n;
 	}
-	else {
-		size_t i = 0, c = 1;
-		knh_float_t v = 0.0, prev = 0.0;
 
-		if(t.buf[0] == '-') i = 1;
-
-		for(;i < t.len; i++) {
-			if('0' <= t.buf[i] && t.buf[i] <= '9') {
-				prev = v;
-				v = v * 10 + (t.buf[i] - '0');
-			}
-			else if(t.buf[i] == '.') {
-				i++;
-				break;
-			}
-			else {
-				return (t.buf[0] == '-') ? -v : v;
-			}
-//			if(!(v > prev)) {
-//				knh_Token_perror(ctx, o, KMSG_FLOATOVERFLOW);
-//				knh_Token_perrata(ctx, o, "0.0");
-//				return 0.0;
-//			}
-		}
-
-		for(; i < t.len; i++) {
-			if('0' <= t.buf[i] && t.buf[i] <= '9') {
-				prev = v;
-				v = v * 10 + (t.buf[i] - '0');
-				c *= 10;
-			}else {
-				break;
-			}
-//			if(!(v > prev)) {
-//				knh_Token_perror(ctx, o, KMSG_FLOATOVERFLOW);
-//				knh_Token_perrata(ctx, o, "0.0");
-//				return 0.0;
-//			}
-		}
-		return (t.buf[0] == '-') ? (-v /c) : (v / c) ;
+	knh_index_t loc = knh_bytes_index(t, 'E');
+	if(loc == -1) loc = knh_bytes_index(t, 'e');
+	if(loc != -1) {
+		t = knh_bytes_first(t, loc);
 	}
+
+	size_t i = 0, c = 1;
+	knh_float_t v = 0.0, prev = 0.0;
+
+	if(t.buf[0] == '-') i = 1;
+
+	for(;i < t.len; i++) {
+		if('0' <= t.buf[i] && t.buf[i] <= '9') {
+			prev = v;
+			v = v * 10 + (t.buf[i] - '0');
+		}
+		else if(t.buf[i] == '.') {
+			i++;
+			break;
+		}
+		else {
+			return (t.buf[0] == '-') ? -v : v;
+		}
+	}
+
+	for(; i < t.len; i++) {
+		if('0' <= t.buf[i] && t.buf[i] <= '9') {
+			prev = v;
+			v = v * 10 + (t.buf[i] - '0');
+			c *= 10;
+		}else {
+			break;
+		}
+	}
+
+	v = (t.buf[0] == '-') ? (-v /c) : (v / c);
+
+	if(loc != -1) {
+		knh_bytes_t t2 = knh_bytes_last(knh_Token_tobytes(o), loc + 1);
+		knh_int_t scale = knh_bytes_toint(t2);
+		if(scale > 0) {
+			for(i = 0; i < scale - 1; i++) {
+				v *= 10;
+			}
+		}
+		else if(scale < 0) {
+			scale = -scale;
+			for(i = 0; i < scale - 1; i++) {
+				v /= 10;
+			}
+		}
+	}
+	return v;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -467,6 +428,11 @@ knh_class_t knh_Token_tagcNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *n
 				continue;
 			}
 		}
+		if((t.buf[i] == 'E' || t.buf[i] == 'e')) {
+			if(isdigit(t.buf[i+1]) || t.buf[i+1] == '-') {
+				continue;
+			}
+		}
 		if(t.buf[i] == '[') {
 			int loc;
 			tag.buf = t.buf + i + 1;
@@ -518,7 +484,11 @@ knh_class_t knh_bytes_guessNUMcid(Ctx *ctx, knh_bytes_t t)
 		}
 		else if(t.buf[i+1] == 0 || t.buf[i+1] == '[' || t.buf[i+1] == ':') {
 			if(t.buf[i] == 'L' || t.buf[i] == 'l') {
+#ifdef CLASS_Int64
 				return CLASS_Int64;
+#else
+				return CLASS_Int;
+#endif
 			}
 		}
 		if(!isdigit(t.buf[i])) break;
@@ -535,7 +505,7 @@ void knh_Token_constNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 	knh_class_t req_bcid = knh_tClass[reqc].bcid;
 	L_TAIL:;
 	if(req_bcid == CLASS_Int) {
-		knh_int_t n = knh_Token_toint(ctx, o);
+		knh_int_t n = knh_Token_tointeger(ctx, o);
 		knh_class_t tagc = knh_Token_tagcNUM(ctx, o, req_bcid, ns);
 		if(tagc == reqc) {
 			knh_Token_setCONST(ctx, o, UP(new_IntX(ctx, reqc, n)));
@@ -552,9 +522,9 @@ void knh_Token_constNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 			knh_Token_setCONST(ctx, o, UP(new_FloatX(ctx, tagc, n)));
 		}
 	}
-	else if(req_bcid == CLASS_Int64) {
-		TODO();
-	}
+//	else if(req_bcid == CLASS_Int64) {
+//		TODO();
+//	}
 #ifdef CLASS_Decimal
 	else if(req_bcid == CLASS_Decimal) {
 		TODO();
@@ -563,26 +533,14 @@ void knh_Token_constNUM(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 	else {
 		knh_bytes_t t = knh_Token_tobytes(o);
 		if(t.buf[0] == '0' && t.buf[1] == 'x') { /* 0x12abcdef */
-			if(t.len > 8+2) {
-				knh_int64_t n = knh_Token_toint64(ctx, o);
-				knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int64, ns);
-				knh_Token_setCONST(ctx, o, UP(new_Int64X(ctx, tagc, n)));
-			}else {
-				knh_int_t n = knh_Token_toint(ctx, o);
-				knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int, ns);
-				knh_Token_setCONST(ctx, o, UP(new_IntX(ctx, tagc, n)));
-			}
+			knh_integer_t n = knh_Token_tointeger(ctx, o);
+			knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int, ns);
+			knh_Token_setCONST(ctx, o, UP(new_IntX(ctx, tagc, n)));
 		}
 		else if(t.buf[0] == '0' && t.buf[1] == 'b') { /* 0b0101011100 */
-			if(t.len > 32+2) {
-				knh_int64_t n = knh_Token_toint64(ctx, o);
-				knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int64, ns);
-				knh_Token_setCONST(ctx, o, UP(new_Int64X(ctx, tagc, n)));
-			}else {
-				knh_int_t n = knh_Token_toint(ctx, o);
-				knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int, ns);
-				knh_Token_setCONST(ctx, o, UP(new_IntX(ctx, tagc, n)));
-			}
+			knh_integer_t n = knh_Token_tointeger(ctx, o);
+			knh_class_t tagc = knh_Token_tagcNUM(ctx, o, CLASS_Int, ns);
+			knh_Token_setCONST(ctx, o, UP(new_IntX(ctx, tagc, n)));
 		}
 		else {
 			req_bcid = knh_bytes_guessNUMcid(ctx, t);
