@@ -1068,23 +1068,26 @@ void knh_Stmt_add_PEXPR(Ctx *ctx, Stmt *stmt, knh_tokens_t *tc)
 /* [OP] */
 
 static
-Token *knh_tokens_findOPNULL(knh_tokens_t *tc)
+int knh_tokens_findOPNULL(Ctx *ctx, knh_tokens_t *tc)
 {
-	int i;
-	Token *op = NULL, **ts = tc->ts;
-	knh_token_t op_type = TT_NAME;
+	int i, oppri = 98, idx = -1;
+	Token **ts = tc->ts;
+
 	for(i = tc->c; i < tc->e; i++) {
-		if(TT_ALTLET < SP(ts[i])->tt && SP(ts[i])->tt < op_type) {
-			op = ts[i];
-			op_type = SP(ts[i])->tt;
+		int p = knh_token_getOpPriority(SP(ts[i])->tt);
+		if(p == 0) {
+			if(SP(ts[i])->tt != TT_DOTS) {
+				knh_Token_perror(ctx, ts[i], KMSG_ESYNTAX);
+			}
+			tc->e = i;
+			break;
+		}
+		if(p <= oppri) {
+			oppri = p;
+			idx = i;
 		}
 	}
-	if (op == NULL) return op;
-	if(knh_token_tomethodn(SP(op)->tt) != METHODN_NONAME
-			|| SP(op)->tt == TT_AND || SP(op)->tt == TT_OR || SP(op)->tt == TT_ALT || SP(op)->tt == TT_QUESTION) {
-		return op;
-	}
-	return NULL;
+	return idx;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1120,7 +1123,7 @@ Stmt *new_StmtOP(Ctx *ctx, knh_tokens_t *tc, Token *op)
 
 	{
 		Stmt *stmt;
-		if(tc->ts[tc->c] == op) {
+		if(SP(tc->ts[tc->c])->tt == SP(op)->tt) {
 			stmt = new_Stmt(ctx, KNH_FLAG_STMTF_ADPOSITION, stt);
 			tc->c += 1;
 		}
@@ -1266,6 +1269,9 @@ Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 	if (oc + 1 == e) {
 		return new_TermVALUE(ctx, ts[oc], lr);
 	}
+	if(SP(ts[oc])->tt == TT_SUB) {
+		SP(ts[oc])->tt = TT_NEG;
+	}
 
 	for(pc = oc; pc < e; pc++) {
 		if(SP(ts[pc])->tt == TT_ERR) {
@@ -1298,10 +1304,44 @@ Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 	}
 
 	/* OPERATOR */ {
-		Token *tk_op = knh_tokens_findOPNULL(tc);
-		if(tk_op != NULL) {
-			//DEBUG("found op %s", knh_Token_tochar(op));
-			return TM(new_StmtOP(ctx, tc, tk_op));
+		int idx = knh_tokens_findOPNULL(ctx, tc);
+		if(idx != -1) {
+			if(knh_token_getOpSize(SP(ts[idx])->tt) == 2) {
+				if(tc->c < idx && idx+1 < tc->e) {
+					Stmt *stmt = new_Stmt(ctx, 0, STT_OP);
+					knh_Stmt_add(ctx, stmt, TM(ts[idx]));
+					knh_tokens_t expr_tc = *tc;
+					expr_tc.e = idx;
+					knh_Stmt_add(ctx, stmt, new_TermEXPR(ctx, &expr_tc, KNH_RVALUE));
+					expr_tc = *tc;
+					expr_tc.c = idx+1;
+					knh_Stmt_add(ctx, stmt, new_TermEXPR(ctx, &expr_tc, KNH_RVALUE));
+					return TM(stmt);
+				}
+				else {
+					knh_Token_perror(ctx, ts[idx], KMSG_UOP2);
+					SP(ts[idx])->tt = TT_ERR; return TM(ts[idx]);
+				}
+			}
+			else if(knh_token_getOpSize(SP(ts[idx])->tt) == 1) {
+				if(SP(ts[idx])->tt == TT_NEXT || SP(ts[idx])->tt == TT_PREV) {
+					return TM(new_StmtOP(ctx, tc, ts[idx]));
+				}
+				else if(tc->c == idx) {
+					Stmt *stmt = new_Stmt(ctx, KNH_FLAG_STMTF_ADPOSITION, STT_OP);
+					knh_Stmt_add(ctx, stmt, TM(ts[idx]));
+					tc->c = idx + 1;
+					knh_Stmt_add(ctx, stmt, new_TermEXPR(ctx, tc, KNH_RVALUE));
+					return TM(stmt);
+				}
+				else {
+					knh_Token_perror(ctx, ts[idx], KMSG_UOP1);
+					SP(ts[idx])->tt = TT_ERR; return TM(ts[idx]);
+				}
+			}
+			else {
+				return TM(new_StmtOP(ctx, tc, ts[idx]));
+			}
 		}
 	}
 
