@@ -938,10 +938,21 @@ void knh_Token_padd(Ctx *ctx, knh_tokenctx_t *tkctx, Token *tk)
 				}
 			}
 		}
+		/* (1+-1) */
+		if(SP(tk)->tt == TT_SUB && knh_token_tomethodn(SP(tkp)->tt) != METHODN_NONAME) {
+			SP(tk)->tt = TT_NEG;
+		}
 	}
+	else {
+		if(SP(tk)->tt == TT_SUB) { /* (- 1) */
+			SP(tk)->tt = TT_NEG;
+		}
+	}
+
 	if(SP(tk)->tt == TT_SEMICOLON || knh_token_isEndOfStmt(SP(tk)->tt)) {
 		knh_Token_setBOL(tk, 1);
 	}
+
 	knh_Token_tokens_add(ctx, tkctx->tk, tk);
 	tkctx->tkcount += 1;
 }
