@@ -109,8 +109,6 @@ typedef struct knh_Boolean_t {
 
 typedef struct knh_Number_t {
 	knh_hObject_t h;
-	knh_int_t   ivalue;
-	knh_float_t value;
 } knh_Number_t;
 
 /* ------------------------------------------------------------------------ */
@@ -119,30 +117,20 @@ typedef struct knh_Number_t {
 
 typedef struct knh_Int_t {
 	knh_hObject_t h;
-	knh_int_t value;
+	struct {
+		knh_integer_t value;
+		knh_uinteger_t uvalue;
+	};
 } knh_Int_t;
 
 typedef knh_Int_t knh_IntX_t;
 
-/* ------------------------------------------------------------------------ */
-/* @class Int64  Number knh_Int64_t @Immutable */
-/* @class Int64X Number knh_Int64_t @Immutable */
-
-typedef struct knh_Int64_t {
-	knh_hObject_t h;
-	knh_int_t   ivalue;
-	knh_int64_t value;
-} knh_Int64_t;
-
-typedef knh_Int64_t knh_Int64X_t;
-
 /* ------------------------------------------------------------------------ */
 /* @class Float Number knh_Float_t @Immutable */
 /* @class FloatX Number knh_Float_t @Immutable */
 
 typedef struct knh_Float_t {
 	knh_hObject_t h;
-	knh_int_t   ivalue;
 	knh_float_t value;
 } knh_Float_t;
 
@@ -198,7 +186,6 @@ typedef struct knh_Array_t {
 	knh_hObject_t h;
 	struct knh_Object_t **list;
 	size_t size;
-//	size_t capacity;
 } knh_Array_t;
 
 /* ------------------------------------------------------------------------ */
@@ -781,11 +768,10 @@ typedef struct knh_Connection {
 } knh_Connection_struct;
 
 #define knh_ResultSet_CTYPE__null    0
-#define knh_ResultSet_CTYPE__int     1
-#define knh_ResultSet_CTYPE__int64   2
-#define knh_ResultSet_CTYPE__float   3
-#define knh_ResultSet_CTYPE__bytes   4
-#define knh_ResultSet_CTYPE__Object  5
+#define knh_ResultSet_CTYPE__integer 1
+#define knh_ResultSet_CTYPE__float   2
+#define knh_ResultSet_CTYPE__bytes   3
+#define knh_ResultSet_CTYPE__Object  4
 
 typedef struct knh_rscolumn_t {
 	knh_type_t type;
@@ -920,38 +906,6 @@ typedef struct knh_Runtime {
 
 #define KONOHA_TABLE_MAGIC   4219881
 
-#define TSTRUCTDB_SIZE  (KONOHA_TSTRUCT_SIZE * sizeof(knh_tstruct_t))
-
-/* ------------------------------------------------------------------------ */
-
-//#ifndef KONOHA_TCLASS_SIZE
-//#define KONOHA_TCLASS_SIZE 256
-//#endif
-//
-//#define TCLASSDB_SIZE  (KONOHA_TCLASS_SIZE * sizeof(knh_tclass_t))
-//
-//#ifndef KONOHA_TFIELDN_SIZE
-//#define KONOHA_TFIELDN_SIZE 256
-//#endif
-//
-//#ifndef KONOHA_TMETHODN_SIZE
-//#define KONOHA_TMETHODN_SIZE 512
-//#endif
-//
-///* ------------------------------------------------------------------------ */
-//
-//typedef struct {
-//	knh_flag_t   flag;
-//	knh_expt_t   parent;
-//	struct knh_String_t     *name;
-//} knh_texpt_t;
-//
-//#ifndef KONOHA_TEXPT_SIZE
-//#define KONOHA_TEXPT_SIZE (KONOHA_TCLASS_SIZE/4)
-//#endif
-//
-//#define TEXPTDB_SIZE  (KONOHA_TEXPT_SIZE * sizeof(knh_texpt_t))
-
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 /* include generated header file */
