@@ -54,16 +54,22 @@ extern "C" {
 #define knh_Bytes_value(o)     (o)->buf
 #define knh_Bytes_last(o)      ((o)->buf + (o)->size)
 #define knh_Bytes_tochar(b)  (char*)knh_Bytes_value(b)
+#define knh_BytesConv_struct_copy NULL
+#define knh_BytesConv_struct_compare NULL
 #define KNH_SIZE(v)         knh_size(v)
 #define B(c)     new_bytes(c)
 #define B2(c,n)   new_bytes__2(c,n)
 #define STEXT(c)  new_bytes__2(c,sizeof(c)-1)
 #define ISB(t,c) (t.len == (sizeof(c)-1) && knh_strncmp((char*)t.buf,c,t.len) == 0)
-#define knh_BytesConv_struct_copy NULL
-#define knh_BytesConv_struct_compare NULL
 #define CLASS_newid          ((knh_class_t)-1)
 #define CLASS_unknown        ((knh_class_t)-2)
 #define knh_Class_cid(c)     (knh_class_t)(c)->cid
+#define knh_ClassMap_struct_copy    NULL
+#define knh_ClassMap_struct_compare  NULL
+#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
+#define knh_ClassStruct_struct_copy    NULL
+#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
+#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define IS_SPEC(o)   (CLASS_IntUnit <= knh_Object_cid(o)  && knh_Object_cid(o) <= CLASS_Vocabulary)
 #define KNH_FLAG_TF_NN                KNH_FLAG_T0
 #define TYPE_ISNULLABLE(t)            ((t & KNH_FLAG_TF_NN)==0)
@@ -78,12 +84,6 @@ extern "C" {
 #define TYPE_any                      CLASS_Any
 #define NNTYPE_any                    CLASS_any
 #define TYPEN(type)  knh_TYPEN(ctx,type)
-#define knh_ClassMap_struct_copy    NULL
-#define knh_ClassMap_struct_compare  NULL
-#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
-#define knh_ClassStruct_struct_copy    NULL
-#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
-#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define knh_Connection_struct_copy    NULL
 #define knh_Connection_struct_compare  NULL
 #define KNH_STDIN          (((Context*)ctx)->in)
@@ -91,9 +91,6 @@ extern "C" {
 #define KNH_STDERR         (((Context*)ctx)->err)
 #define knh_DictIdx_struct_copy   NULL
 #define new_DictSet(ctx, c)   new_DictSet0(ctx, c)
-#define EXPT_newid            ((knh_expt_t)0)
-#define EXPT_Exception        ((knh_expt_t)1)
-#define EXPT_NoSuchException  ((knh_expt_t)2)
 #define knh_Exception_eid(o)   (o)->eid
 #define knh_Exception_struct_copy   NULL
 #define knh_Exception_struct_compare  NULL
@@ -184,6 +181,8 @@ extern "C" {
 #define DEBUG_ASSERT_cid(cid)    KNH_ASSERT(IS_cid(cid))
 #define CLASSN(cid)   knh_String_tochar(knh_tClass[cid].lname)
 #define CLASSNo(o)    knh_String_tochar(knh_tClass[(o)->h.cid].lname)
+#define DEBUG_ASSERT_eid(cid)    KNH_ASSERT(IS_eid(cid))
+#define EXPTN(eid)   knh_String_tochar(knh_tExpt_name(eid))
 #define KNH_TMAPMAP  KNH_TMAPPER
 #define FIELDN_NONAME    ((knh_fieldn_t)-1)
 #define FIELDN_NEWID     ((knh_fieldn_t)-2)
@@ -223,7 +222,6 @@ extern "C" {
 #define knh_tMethodField(n)                 (MethodField*)knh_Array_n(DP(knh_rootSystem)->tMethodFields, n)
 #define knh_tMethodField_size               knh_Array_size(DP(knh_rootSystem)->tMethodFields)
 #define new_Int(ctx, n)      new_Int__fast(ctx, CLASS_Int, (n))
-#define new_Int64(ctx, n)      new_Int64__fast(ctx, CLASS_Int64, (n))
 #define new_Float(ctx, n)      new_Float__fast(ctx, CLASS_Float, (n))
 #define new_String__T(ctx, text)    new_StringX__T(ctx, CLASS_String, text)
 #define KNH_FLAG_SF_FIELD          KNH_FLAG_T1
@@ -294,15 +292,14 @@ KNHAPI(void) konoha_addRegexDriver(Ctx *ctx, char *alias, knh_regex_drvapi_t *d)
 KNHAPI(ResultSet*) new_ResultSet(Ctx *ctx, Connection *conn, size_t column_size, knh_rshdlr_t *rsptr);
 KNHAPI(void) knh_ResultSet_initMetaInfo(Ctx *ctx, ResultSet *o, size_t n, knh_type_t type, String *name);
 KNHAPI(void) knh_ResultSet_initData(Ctx *ctx, ResultSet *o);
-KNHAPI(void) knh_ResultSet_setInt(Ctx *ctx, ResultSet *o, size_t n, knh_int_t value);
+KNHAPI(void) knh_ResultSet_setInt(Ctx *ctx, ResultSet *o, size_t n, knh_integer_t value);
 KNHAPI(void) knh_ResultSet_setFloat(Ctx *ctx, ResultSet *o, size_t n, knh_float_t value);
-KNHAPI(void) knh_ResultSet_setInt64(Ctx *ctx, ResultSet *o, size_t n, knh_int64_t value);
 KNHAPI(void) knh_ResultSet_setBytes(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t);
 KNHAPI(void) knh_ResultSet_setNULL(Ctx *ctx, ResultSet *o, size_t n);
 KNHAPI(void) konoha_addAliasURN(Ctx *ctx, char *alias, char *urn);
-KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
 KNHAPI(ClassSpec*) new_Vocabulary(Ctx *ctx, char *lang, char *defval, ...);
 KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text);
+KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
 KNHAPI(konoha_t) konoha_open(void);
 KNHAPI(void) konoha_close(konoha_t konoha);
 KNHAPI(Ctx*) konoha_open_context(konoha_t konoha);
@@ -315,7 +312,6 @@ KNHAPI(knh_class_t) konoha_addVirtualClass(Ctx *ctx, char *name, int method_size
 KNHAPI(void) konoha_addMethod(Ctx *ctx, char *kscript, f_method f);
 KNHAPI(void) konoha_addConst(Ctx *ctx, char *name, Object *o);
 KNHAPI(void) konoha_addIntConst(Ctx *ctx, char *name, knh_int_t value);
-KNHAPI(void) konoha_addInt64Const(Ctx *ctx, char *name, knh_int64_t value);
 KNHAPI(void) konoha_addFloatConst(Ctx *ctx, char *name, knh_float_t value);
 KNHAPI(void) konoha_addStringConst(Ctx *ctx, char *name, char *text);
 KNHAPI(void) konoha_addDriver(Ctx *ctx, char *name, int type, void *drv);
@@ -323,8 +319,7 @@ KNHAPI(void) konoha_shell(Ctx *ctx);
 KNHAPI(size_t) knh_stat_usedMemorySize(void);
 KNHAPI(f_traverse) konoha_sweep();
 KNHAPI(int) konoha_issweep(f_traverse ftr);
-KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_int_t value);
-KNHAPI(Int64*) new_Int64__fast(Ctx *ctx, knh_class_t cid, knh_int64_t value);
+KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value);
 KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value);
 KNHAPI(void) konoha_addParserDriver(Ctx *ctx, char *alias, knh_parser_drvapi_t *d);
 KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, f_makespec func);
