@@ -110,6 +110,7 @@ void knh_oarray_free(Ctx *ctx, knh_Object_t **a);
 /* ../class/konoha/knh_Boolean.c */
 Object *knh_Boolean_fdefault(Ctx *ctx, knh_class_t cid);
 /* ../class/konoha/knh_Boolean_api1.c */
+METHOD knh__Boolean_opNot(Ctx *ctx, knh_sfp_t *sfp);
 String* knh_Boolean_String(Ctx *ctx, Boolean *o, Mapper *mpr);
 Boolean* knh_String_Boolean(Ctx *ctx, String *o, Mapper *mpr);
 void knh_Boolean__s(Ctx *ctx, Boolean *o, OutputStream *w, String *m);
@@ -122,6 +123,17 @@ void knh_Bytes_clear(Bytes *o);
 void knh_Bytes_putc(Ctx *ctx, Bytes *o, int ch);
 void knh_Bytes_write(Ctx *ctx, Bytes *o, knh_bytes_t v);
 void knh_Bytes_unputc(Bytes *o);
+/* ../class/konoha/knh_BytesConv.c */
+void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
+void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
+size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
+BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
+BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
+BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
+BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
+String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
+String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
+void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Bytes_api1.c */
 METHOD knh__Bytes_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Bytes_putc(Ctx *ctx, knh_sfp_t *sfp);
@@ -155,36 +167,11 @@ knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_int_t ch);
 knh_int_t knh_bytes_toint(knh_bytes_t t);
 knh_float_t knh_bytes_tofloat(knh_bytes_t t);
 knh_int64_t knh_bytes_toint64(knh_bytes_t t);
-/* ../class/konoha/knh_BytesConv.c */
-void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
-void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
-size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
-BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
-BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
-BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
-BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
-String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
-String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
-void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Class.c */
 knh_Class_t *new_Class__type(Ctx *ctx, knh_type_t type);
 Object *knh_Class_fdefault(Ctx *ctx, knh_class_t cid);
 knh_hcode_t knh_Class_hashCode(Class *o);
 int knh_Class_compareTo(Class *o, Class *o2);
-/* ../class/konoha/knh_Class_api1.c */
-void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_Class_type_t.c */
-knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
-knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
-knh_class_t knh_class_Array(Ctx *ctx, knh_class_t p1);
-knh_class_t knh_class_Iterator(Ctx *ctx, knh_class_t p1);
-knh_class_t knh_pmzclass(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
-knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t);
-char *TYPEQ(knh_type_t type);
-char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 /* ../class/konoha/knh_ClassMap.c */
 void knh_ClassMap_struct_init(Ctx *ctx, knh_ClassMap_struct *b, int init, Object *cs);
 void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, f_traverse gc);
@@ -206,6 +193,20 @@ void knh_Class_addMethod__fast(Ctx *ctx, knh_class_t cid, Method *mtd);
 void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
 Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
 void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
+/* ../class/konoha/knh_Class_api1.c */
+void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m);
+/* ../class/konoha/knh_Class_type_t.c */
+knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
+knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
+knh_class_t knh_class_Array(Ctx *ctx, knh_class_t p1);
+knh_class_t knh_class_Iterator(Ctx *ctx, knh_class_t p1);
+knh_class_t knh_pmzclass(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
+knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t);
+char *TYPEQ(knh_type_t type);
+char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 /* ../class/konoha/knh_Connection.c */
 knh_db_drvapi_t * knh_System_getDataBaseDriver(Ctx *ctx, knh_bytes_t name);
 void knh_Connection_struct_init(Ctx *ctx, knh_Connection_struct *b, int init, Object *cs);
@@ -256,25 +257,6 @@ String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid);
 String* knh_DictIdx_get(DictIdx *o, knh_int_t termid);
 void knh_DictIdx_clear(Ctx *ctx, DictIdx *o);
 void knh_DictIdx__k(Ctx *ctx, DictIdx *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_DictMap_api1.c */
-METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
-METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
-Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
-Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
-METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictMapSet.c */
 knh_dict_t* knh_dict_resize(Ctx *ctx, knh_dict_t *a, size_t newsize);
 void knh_dict_traverse(Ctx *ctx, knh_dict_t *a, f_traverse ftr);
@@ -309,6 +291,25 @@ void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uint_t n);
 void knh_DictSet_add(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_remove(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_clear(Ctx *ctx, DictSet *o);
+/* ../class/konoha/knh_DictMap_api1.c */
+METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
+METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
+Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
+Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
+Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
+METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
+void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictSet_api1.c */
 METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp);
@@ -335,9 +336,6 @@ void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse
 Exception* new_Exception(Ctx *ctx, String *msg);
 Exception* new_Exception__b(Ctx *ctx, knh_bytes_t msg);
 Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue);
-/* ../class/konoha/knh_Exception_api1.c */
-void knh_Exception__s(Ctx *ctx, Exception *b, OutputStream *w, String *m);
-void knh_Exception__dump(Ctx *ctx, Exception *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_ExceptionHandler.c */
 void knh_ExceptionHandler_struct_init(Ctx *ctx, knh_ExceptionHandler_struct *b, int init, Object *cs);
 void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, f_traverse gc);
@@ -345,6 +343,9 @@ ExceptionHandler* new_ExceptionHandler(Ctx *ctx);
 Object *knh_ExceptionHandler_fdefault(Ctx *ctx, knh_class_t cid);
 void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *b, Exception *e);
 Exception* knh_ExceptionHandler_getCaughtException(ExceptionHandler *b);
+/* ../class/konoha/knh_Exception_api1.c */
+void knh_Exception__s(Ctx *ctx, Exception *b, OutputStream *w, String *m);
+void knh_Exception__dump(Ctx *ctx, Exception *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_Float.c */
 Float* new_FloatX0(Ctx *ctx, knh_class_t cid, knh_float_t value);
 Float* new_FloatX(Ctx *ctx, knh_class_t cid, knh_float_t value);
@@ -355,17 +356,19 @@ int knh_Float_compareTo(Float *o, Float *o2);
 char *knh_format_Float(char *buf, size_t bufsiz, Float *o);
 knh_float_t knh_float_max(knh_float_t a, knh_float_t b);
 knh_float_t knh_float_min(knh_float_t a, knh_float_t b);
+/* ../class/konoha/knh_FloatUnit.c */
+void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
+void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, f_traverse gc);
+FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
+void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
+void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
+void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
 /* ../class/konoha/knh_Float_api1.c */
-METHOD knh__Float_opAdd__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opNg(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opSub__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opMul__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opDiv__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opMod(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp);
@@ -375,23 +378,17 @@ METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Float_getSize(Ctx *ctx, knh_sfp_t *sfp);
 Float* knh_String_Float(Ctx *ctx, String *s, Mapper *mpr);
 String* knh_Float_String(Ctx *ctx, Float *o, Mapper *mpr);
 Float* knh_Int_Float(Ctx *ctx, Int *o, Mapper *mpr);
 Int* knh_Float_Int(Ctx *ctx, Float *o, Mapper *mpr);
-void knh_Float__s(Ctx *ctx, Float *b, OutputStream *w, String *m);
-void knh_Float__d(Ctx *ctx, Int *o, OutputStream *w, String *m);
-void knh_Float__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
-void knh_Float__k(Ctx *ctx, Float *b, OutputStream *w, String *m);
+void knh_Float__s(Ctx *ctx, Float *o, OutputStream *w, String *m);
+void knh_Float__d(Ctx *ctx, Float *o, OutputStream *w, String *m);
+void knh_Float__f(Ctx *ctx, Float *o, OutputStream *w, String *m);
+void knh_Float__k(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__bits(Ctx *ctx, Float *o, OutputStream *w, String *m);
-void knh_Float__dump(Ctx *ctx, Float *b, OutputStream *w, String *m);
-/* ../class/konoha/knh_FloatUnit.c */
-void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
-void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, f_traverse gc);
-FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
-void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
-void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
-void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
+void knh_Float__dump(Ctx *ctx, Float *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_HashMap.c */
 void knh_HashMap_struct_init(Ctx *ctx, knh_HashMap_struct *b, int init, Object *cs);
 knh_hashmapentry_t *new_hashmapentry(Ctx *ctx, HashMap *o);
@@ -440,8 +437,8 @@ void knh_InputStream__dump(Ctx *ctx, InputStream *b, OutputStream *w, String *m)
 Iterator* knh_InputStream_String__(Ctx *ctx, InputStream *o, Mapper *mpr);
 void knh_InputStream__k(Ctx *ctx, InputStream *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Int.c */
-Int* new_IntX0(Ctx *ctx, knh_class_t cid, knh_int_t value);
-Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_int_t value);
+Int* new_IntX0(Ctx *ctx, knh_class_t cid, knh_integer_t value);
+Int *new_IntX(Ctx *ctx, knh_class_t cid, knh_integer_t value);
 Int *new_IntX__b(Ctx *ctx, knh_class_t cid, knh_bytes_t t);
 Object *knh_Int_cspec(Ctx *ctx);
 Object *knh_Int_fdefault(Ctx *ctx, knh_class_t cid);
@@ -453,22 +450,18 @@ knh_int_t knh_int_max(knh_int_t a, knh_int_t b);
 knh_int_t knh_int_min(knh_int_t a, knh_int_t b);
 knh_uint_t knh_uint_max(knh_uint_t a, knh_uint_t b);
 knh_uint_t knh_uint_min(knh_uint_t a, knh_uint_t b);
-knh_int_t knh_IntNULL_toint(Int *v);
-/* ../class/konoha/knh_Int64.c */
-Int64* new_Int64X__fast(Ctx *ctx, knh_class_t cid, knh_int64_t value);
-Int64* new_Int64X(Ctx *ctx, knh_class_t cid, knh_int64_t value);
-knh_int64_t knh_int64_max(knh_int64_t a, knh_int64_t b);
-knh_int64_t knh_int64_min(knh_int64_t a, knh_int64_t b);
-knh_uint64_t knh_uint64_max(knh_uint64_t a, knh_uint64_t b);
-knh_uint64_t knh_uint64_min(knh_uint64_t a, knh_uint64_t b);
-void knh_Int64__dump(Ctx *ctx, Int64 *b, OutputStream *w, String *m);
+knh_integer_t knh_IntNULL_toint(Int *v);
+/* ../class/konoha/knh_IntUnit.c */
+void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
+void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max);
+void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v);
 /* ../class/konoha/knh_Int_api1.c */
-METHOD knh__Int_opAdd__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opNg(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opSub__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opMul__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opDiv__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp);
@@ -497,14 +490,6 @@ void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__x(Ctx *ctx, Int *b, OutputStream *w, String *m);
 void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits);
 void knh_Int__bits(Ctx *ctx, Int *b, OutputStream *w, String *m);
-/* ../class/konoha/knh_IntUnit.c */
-void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
-void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max);
-void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
@@ -599,21 +584,12 @@ void knh_Nue__k(Ctx *ctx, Nue *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_Number.c */
 knh_int_t knh_Number_toint(Any *o);
 knh_int64_t knh_Number_toint64(Any *o);
+knh_integer_t knh_Number_tointeger(Any *o);
 knh_float_t knh_Number_tofloat(Any *o);
 knh_int_t knh_Int_toint(Int *o);
 knh_float_t knh_Int_tofloat(Int *o);
 knh_int64_t knh_Int_toint64(Int *o);
-knh_int_t knh_Float_toint(Float *o);
-knh_float_t knh_Float_tofloat(Float *o);
-knh_int64_t knh_Float_toint64(Float *o);
-knh_int_t knh_Int64_toint(Int64 *o);
-knh_float_t knh_Int64_tofloat(Int64 *o);
-knh_int64_t knh_Int64_toint64(Int64 *o);
 /* ../class/konoha/knh_Number_api1.c */
-METHOD knh__Number_opAdd__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Number_opSub__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Number_opMul__2(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Number_opDiv__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Number_opAdd(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Number_opSub(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Number_opMul(Ctx *ctx, knh_sfp_t *sfp);
@@ -640,7 +616,6 @@ METHOD knh__Object_opLt(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opLte(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opGt(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opGte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opNot(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opIs(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opIsa(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp);
@@ -706,9 +681,8 @@ void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
 knh_index_t knh_ResultSet_index(Ctx *ctx, ResultSet *o, knh_bytes_t name);
 String *knh_ResultSet_getName(Ctx *ctx, ResultSet *o, size_t n);
 knh_type_t knh_ResultSet_get_type(Ctx *ctx, ResultSet *o, size_t n);
-knh_int_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
+knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
 knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
-knh_int64_t knh_ResultSet_getInt64(Ctx *ctx, ResultSet *o, size_t n);
 void knh_ResultSet__dump(Ctx *ctx, ResultSet *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Runtime.c */
 int knh_Runtime_isAllClosed(void);
@@ -738,20 +712,23 @@ int knh_String_compareTo(String *o, String *o2);
 char *knh_StringNULL_tochar(String *o);
 knh_bytes_t knh_String_tobytes(String *o);
 knh_bytes_t knh_StringNULL_tobytes(String *o);
+/* ../class/konoha/knh_StringUnit.c */
+void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
+void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
+StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
+Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_String_api1.c */
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
 knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
 knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
 METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_getSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opAdd__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opSub__2(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opMul__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opDiv__2(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opHas(Ctx *ctx, knh_sfp_t *sfp);
@@ -769,11 +746,6 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m);
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
 knh_bytes_t knh_bytes_mofflen(knh_bytes_t m, size_t moff, size_t mlen);
-/* ../class/konoha/knh_StringUnit.c */
-void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
-void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
-StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
-Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_System.c */
 Object *knh_System_fdefault(Ctx *ctx, knh_class_t cid);
 char * knh_bytes_nzenvkey(knh_bytes_t t, char *buf, size_t bufsiz);
@@ -896,8 +868,6 @@ Stmt *knh_Stmt_tail(Stmt *o);
 Stmt* knh_StmtNULL_tail_append(Ctx *ctx, Stmt *o, Stmt *stmt);
 void knh_Stmt__s(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
 void knh_Stmt__dump(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
-/* ../class/konohac/knh_Stmt_const.c */
-Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_StmtCLASS.c */
 void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid);
 void knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
@@ -948,6 +918,8 @@ void knh_Stmt_cmpl_beforeLABEL(Ctx *ctx, Stmt *stmt, Compiler *cpr, int level);
 void knh_Stmt_cmpl_afterLABEL(Ctx *ctx, Stmt *stmt, Compiler *cpr, int level);
 void knh_StmtIF_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns,int level);
 void knh_StmtIF_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtSWITCH_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns,int level);
+void knh_StmtSWITCH_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtALT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtAND_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
@@ -961,6 +933,10 @@ void knh_StmtBREAK_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 void knh_StmtGOTO_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtFOR_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtFOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtTRY_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
+void knh_StmtTRY_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtTHROW_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
+void knh_StmtTHROW_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtMETA.c */
 knh_bool_t knh_Stmt_hasMeta(Stmt *o);
 void knh_StmtMETA_add_prestmt(Ctx *ctx, Stmt *o, knh_tokens_t *tc, int start);
@@ -994,6 +970,8 @@ void knh_StmtUUNIT_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 void knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUMAPMAP_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUALIAS(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
+/* ../class/konohac/knh_Stmt_const.c */
+Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_Term.c */
 knh_type_t knh_Term_type(Term *tm);
 Token *knh_Term_firstToken(Term *tm);
@@ -1022,6 +1000,14 @@ knh_bytes_t knh_Token_tobytes(Token *o);
 void knh_Token__s(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__k(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__dump(Ctx *ctx, Token *o, OutputStream *w, String *m);
+/* ../class/konohac/knh_tokens_t.c */
+Token* knh_tokens_curToken(knh_tokens_t *tc);
+int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
+void knh_tokens_nextStmt(knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
+String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
+void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../class/konohac/knh_Token_const.c */
 Token* new_TokenCONST(Ctx *ctx, Any *fln, Any *data);
 void knh_Token_setCONST(Ctx *ctx, Token *o, Any *data);
@@ -1033,14 +1019,6 @@ void knh_Token_setLCONST(Ctx *ctx, Token *tk, NameSpace *ns);
 knh_bool_t knh_Token_isSystemVariable(Token *tk);
 void knh_Token_constSystemVariable(Ctx *ctx, Token *tk, Compiler *cpr);
 Token *knh_Token_const(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns);
-/* ../class/konohac/knh_tokens_t.c */
-Token* knh_tokens_curToken(knh_tokens_t *tc);
-int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
-void knh_tokens_nextStmt(knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
-String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
-void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../konoha/deps/cygwin/filesystem__cygwin.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
@@ -1053,6 +1031,12 @@ char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../konoha/deps/tb/filesystem__tb.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../konoha/deps/tb/system__bt.c */
+char* ALT_getenv(const char *name);
+void *ALT_dlopen(const char* path, int mode);
+void *ALT_dlsym(void* handle, const char* symbol);
+const char *ALT_dlerror();
+int ALT_dlclose(void* handle);
 /* ../konoha/deps/win32/filesystem__win32.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
@@ -1100,6 +1084,17 @@ void knh_tContext_init0(void);
 knh_Context_t *new_Context0(Runtime *runtime, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, f_traverse ftr);
 void knh_tContext_traverse(Ctx* ctx, f_traverse f);
+/* ../konoha/runtime/knh_tException.c */
+void knh_tExpt_init0(void);
+void knh_tExpt_traverse(Ctx *ctx, f_traverse ftr);
+knh_class_t knh_tExpt_newId(Ctx *ctx);
+int IS_eid(knh_expt_t eid);
+knh_flag_t knh_tExpt_flag(knh_expt_t eid);
+knh_expt_t knh_tExpt_parent(knh_expt_t eid);
+knh_bool_t knh_tExpt_isa(knh_expt_t eid, knh_expt_t parent);
+String *knh_tExpt_name(knh_expt_t eid);
+knh_expt_t knh_texpt_forname(Ctx *ctx, knh_bytes_t msg, knh_expt_t def);
+knh_expt_t KNH_TEXPT(Ctx *ctx, knh_flag_t flag, knh_class_t eid, String *name, char *pname);
 /* ../konoha/runtime/knh_tMapper.c */
 void KNH_TMAPPER(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, f_mapper fmap, Object *mapdata);
 Object* knh_Mapper_fInterface(Ctx *ctx, Object *o, Mapper *mpr);
