@@ -56,127 +56,133 @@ extern "C" {
 #define TT_ASPECT                       ((knh_token_t)13)
 #define TT_IF                           ((knh_token_t)14)
 #define TT_ELSE                         ((knh_token_t)15)
-#define TT_WHILE                        ((knh_token_t)16)
-#define TT_DO                           ((knh_token_t)17)
-#define TT_FOR                          ((knh_token_t)18)
-#define TT_FOREACH                      ((knh_token_t)19)
-#define TT_FROM                         ((knh_token_t)20)
-#define TT_WHERE                        ((knh_token_t)21)
-#define TT_BREAK                        ((knh_token_t)22)
-#define TT_CONTINUE                     ((knh_token_t)23)
-#define TT_GOTO                         ((knh_token_t)24)
-#define TT_TRY                          ((knh_token_t)25)
-#define TT_CATCH                        ((knh_token_t)26)
-#define TT_FINALLY                      ((knh_token_t)27)
-#define TT_THROW                        ((knh_token_t)28)
-#define TT_PRINT                        ((knh_token_t)29)
-#define TT_ASSERT                       ((knh_token_t)30)
-#define TT_BRACE                        ((knh_token_t)31)
-#define TT_PARENTHESIS                  ((knh_token_t)32)
-#define TT_BRANCET                      ((knh_token_t)33)
-#define TT_DOTS                         ((knh_token_t)34)
-#define TT_SEMICOLON                    ((knh_token_t)35)
-#define TT_COMMA                        ((knh_token_t)36)
-#define TT_LET                          ((knh_token_t)37)
-#define TT_LSHIFTE                      ((knh_token_t)38)
-#define TT_RSHIFTE                      ((knh_token_t)39)
-#define TT_ADDE                         ((knh_token_t)40)
-#define TT_SUBE                         ((knh_token_t)41)
-#define TT_MULE                         ((knh_token_t)42)
-#define TT_DIVE                         ((knh_token_t)43)
-#define TT_MODE                         ((knh_token_t)44)
-#define TT_BITORE                       ((knh_token_t)45)
-#define TT_BITANDE                      ((knh_token_t)46)
-#define TT_ALTLET                       ((knh_token_t)47)
-#define TT_QUESTION                     ((knh_token_t)48)
-#define TT_SUBSETE                      ((knh_token_t)49)
-#define TT_SUBSET                       ((knh_token_t)50)
-#define TT_OFFSET                       ((knh_token_t)51)
-#define TT_COLON                        ((knh_token_t)52)
-#define TT_OR                           ((knh_token_t)53)
-#define TT_AND                          ((knh_token_t)54)
-#define TT_NOT                          ((knh_token_t)55)
-#define TT_INSTANCEOF                   ((knh_token_t)56)
-#define TT_ISA                          ((knh_token_t)57)
-#define TT_AS                           ((knh_token_t)58)
-#define TT_HAS                          ((knh_token_t)59)
-#define TT_IS                           ((knh_token_t)60)
-#define TT_TO                           ((knh_token_t)61)
-#define TT_EQ                           ((knh_token_t)62)
-#define TT_NEQ                          ((knh_token_t)63)
-#define TT_LT                           ((knh_token_t)64)
-#define TT_LTE                          ((knh_token_t)65)
-#define TT_GT                           ((knh_token_t)66)
-#define TT_GTE                          ((knh_token_t)67)
-#define TT_LOR                          ((knh_token_t)68)
-#define TT_FMT                          ((knh_token_t)69)
-#define TT_LSHIFT                       ((knh_token_t)70)
-#define TT_RSHIFT                       ((knh_token_t)71)
-#define TT_ADD                          ((knh_token_t)72)
-#define TT_SUB                          ((knh_token_t)73)
-#define TT_DIV                          ((knh_token_t)74)
-#define TT_MOD                          ((knh_token_t)75)
-#define TT_MUL                          ((knh_token_t)76)
-#define TT_LAND                         ((knh_token_t)77)
-#define TT_ALT                          ((knh_token_t)78)
-#define TT_LNOT                         ((knh_token_t)79)
-#define TT_XOR                          ((knh_token_t)80)
-#define TT_NEXT                         ((knh_token_t)81)
-#define TT_PREV                         ((knh_token_t)82)
-#define TT_NUM                          ((knh_token_t)83)
+#define TT_SWITCH                       ((knh_token_t)16)
+#define TT_CASE                         ((knh_token_t)17)
+#define TT_WHILE                        ((knh_token_t)18)
+#define TT_DO                           ((knh_token_t)19)
+#define TT_FOR                          ((knh_token_t)20)
+#define TT_FOREACH                      ((knh_token_t)21)
+#define TT_FROM                         ((knh_token_t)22)
+#define TT_WHERE                        ((knh_token_t)23)
+#define TT_BREAK                        ((knh_token_t)24)
+#define TT_CONTINUE                     ((knh_token_t)25)
+#define TT_GOTO                         ((knh_token_t)26)
+#define TT_TRY                          ((knh_token_t)27)
+#define TT_CATCH                        ((knh_token_t)28)
+#define TT_FINALLY                      ((knh_token_t)29)
+#define TT_THROW                        ((knh_token_t)30)
+#define TT_PRINT                        ((knh_token_t)31)
+#define TT_ASSERT                       ((knh_token_t)32)
+#define TT_BRACE                        ((knh_token_t)33)
+#define TT_PARENTHESIS                  ((knh_token_t)34)
+#define TT_BRANCET                      ((knh_token_t)35)
+#define TT_DOTS                         ((knh_token_t)36)
+#define TT_SEMICOLON                    ((knh_token_t)37)
+#define TT_COMMA                        ((knh_token_t)38)
+#define TT_LET                          ((knh_token_t)39)
+#define TT_LSHIFTE                      ((knh_token_t)40)
+#define TT_RSHIFTE                      ((knh_token_t)41)
+#define TT_ADDE                         ((knh_token_t)42)
+#define TT_SUBE                         ((knh_token_t)43)
+#define TT_MULE                         ((knh_token_t)44)
+#define TT_DIVE                         ((knh_token_t)45)
+#define TT_MODE                         ((knh_token_t)46)
+#define TT_BITORE                       ((knh_token_t)47)
+#define TT_BITANDE                      ((knh_token_t)48)
+#define TT_ALTLET                       ((knh_token_t)49)
+#define TT_QUESTION                     ((knh_token_t)50)
+#define TT_SUBSETE                      ((knh_token_t)51)
+#define TT_SUBSET                       ((knh_token_t)52)
+#define TT_OFFSET                       ((knh_token_t)53)
+#define TT_COLON                        ((knh_token_t)54)
+#define TT_ALT                          ((knh_token_t)55)
+#define TT_OR                           ((knh_token_t)56)
+#define TT_AND                          ((knh_token_t)57)
+#define TT_NOT                          ((knh_token_t)58)
+#define TT_INSTANCEOF                   ((knh_token_t)59)
+#define TT_ISA                          ((knh_token_t)60)
+#define TT_AS                           ((knh_token_t)61)
+#define TT_HAS                          ((knh_token_t)62)
+#define TT_IS                           ((knh_token_t)63)
+#define TT_TO                           ((knh_token_t)64)
+#define TT_EQ                           ((knh_token_t)65)
+#define TT_NEQ                          ((knh_token_t)66)
+#define TT_LT                           ((knh_token_t)67)
+#define TT_LTE                          ((knh_token_t)68)
+#define TT_GT                           ((knh_token_t)69)
+#define TT_GTE                          ((knh_token_t)70)
+#define TT_LOR                          ((knh_token_t)71)
+#define TT_FMT                          ((knh_token_t)72)
+#define TT_LSHIFT                       ((knh_token_t)73)
+#define TT_RSHIFT                       ((knh_token_t)74)
+#define TT_ADD                          ((knh_token_t)75)
+#define TT_SUB                          ((knh_token_t)76)
+#define TT_DIV                          ((knh_token_t)77)
+#define TT_MOD                          ((knh_token_t)78)
+#define TT_MUL                          ((knh_token_t)79)
+#define TT_LAND                         ((knh_token_t)80)
+#define TT_LNOT                         ((knh_token_t)81)
+#define TT_XOR                          ((knh_token_t)82)
+#define TT_NEXT                         ((knh_token_t)83)
+#define TT_PREV                         ((knh_token_t)84)
+#define TT_NEG                          ((knh_token_t)85)
+#define TT_NUM                          ((knh_token_t)86)
 #define knh_Token_isNUM(tk_)            (SP(tk_)->tt == TT_NUM)
-#define TT_STR                          ((knh_token_t)84)
+#define TT_STR                          ((knh_token_t)87)
 #define knh_Token_isSTR(tk_)            (SP(tk_)->tt == TT_STR)
-#define TT_TSTR                         ((knh_token_t)85)
+#define TT_TSTR                         ((knh_token_t)88)
 #define knh_Token_isTSTR(tk_)           (SP(tk_)->tt == TT_TSTR)
-#define TT_FMTSTR                       ((knh_token_t)86)
+#define TT_FMTSTR                       ((knh_token_t)89)
 #define knh_Token_isFMTSTR(tk_)         (SP(tk_)->tt == TT_FMTSTR)
-#define TT_LABEL                        ((knh_token_t)87)
+#define TT_LABEL                        ((knh_token_t)90)
 #define knh_Token_isLABEL(tk_)          (SP(tk_)->tt == TT_LABEL)
-#define TT_METAN                        ((knh_token_t)88)
+#define TT_METAN                        ((knh_token_t)91)
 #define knh_Token_isMETAN(tk_)          (SP(tk_)->tt == TT_METAN)
-#define TT_PROPN                        ((knh_token_t)89)
+#define TT_PROPN                        ((knh_token_t)92)
 #define knh_Token_isPROPN(tk_)          (SP(tk_)->tt == TT_PROPN)
-#define TT_URN                          ((knh_token_t)90)
+#define TT_URN                          ((knh_token_t)93)
 #define knh_Token_isURN(tk_)            (SP(tk_)->tt == TT_URN)
-#define TT_MT                           ((knh_token_t)91)
+#define TT_MT                           ((knh_token_t)94)
 #define knh_Token_isMT(tk_)             (SP(tk_)->tt == TT_MT)
-#define TT_CONSTN                       ((knh_token_t)92)
+#define TT_CONSTN                       ((knh_token_t)95)
 #define knh_Token_isCONSTN(tk_)         (SP(tk_)->tt == TT_CONSTN)
-#define TT_TYPEN                        ((knh_token_t)93)
+#define TT_TYPEN                        ((knh_token_t)96)
 #define knh_Token_isTYPEN(tk_)          (SP(tk_)->tt == TT_TYPEN)
-#define TT_CMETHODN                     ((knh_token_t)94)
+#define TT_CMETHODN                     ((knh_token_t)97)
 #define knh_Token_isCMETHODN(tk_)       (SP(tk_)->tt == TT_CMETHODN)
-#define TT_NAME                         ((knh_token_t)95)
+#define TT_NAME                         ((knh_token_t)98)
 #define knh_Token_isNAME(tk_)           (SP(tk_)->tt == TT_NAME)
-#define TT_MN                           ((knh_token_t)96)
+#define TT_MN                           ((knh_token_t)99)
 #define knh_Token_isMN(tk_)             (SP(tk_)->tt == TT_MN)
-#define TT_FN                           ((knh_token_t)97)
+#define TT_FN                           ((knh_token_t)100)
 #define knh_Token_isFN(tk_)             (SP(tk_)->tt == TT_FN)
-#define TT_CID                          ((knh_token_t)98)
+#define TT_CID                          ((knh_token_t)101)
 #define knh_Token_isCID(tk_)            (SP(tk_)->tt == TT_CID)
-#define TT_CONST                        ((knh_token_t)99)
+#define TT_CONST                        ((knh_token_t)102)
 #define knh_Token_isCONST(tk_)          (SP(tk_)->tt == TT_CONST)
-#define TT_MTDMPR                       ((knh_token_t)100)
+#define TT_MTDMPR                       ((knh_token_t)103)
 #define knh_Token_isMTDMPR(tk_)         (SP(tk_)->tt == TT_MTDMPR)
-#define TT_EBPIDX                       ((knh_token_t)101)
+#define TT_EBPIDX                       ((knh_token_t)104)
 #define knh_Token_isEBPIDX(tk_)         (SP(tk_)->tt == TT_EBPIDX)
-#define TT_SFPIDX                       ((knh_token_t)102)
+#define TT_SFPIDX                       ((knh_token_t)105)
 #define knh_Token_isSFPIDX(tk_)         (SP(tk_)->tt == TT_SFPIDX)
-#define TT_FLDIDX                       ((knh_token_t)103)
+#define TT_FLDIDX                       ((knh_token_t)106)
 #define knh_Token_isFLDIDX(tk_)         (SP(tk_)->tt == TT_FLDIDX)
-#define TT_OBJIDX                       ((knh_token_t)104)
+#define TT_OBJIDX                       ((knh_token_t)107)
 #define knh_Token_isOBJIDX(tk_)         (SP(tk_)->tt == TT_OBJIDX)
-#define TT_SYSCONST                     ((knh_token_t)105)
+#define TT_SYSCONST                     ((knh_token_t)108)
 #define knh_Token_isSYSCONST(tk_)       (SP(tk_)->tt == TT_SYSCONST)
-#define TT_ASIS                         ((knh_token_t)106)
-#define TT_ERR                          ((knh_token_t)107)
+#define TT_ASIS                         ((knh_token_t)109)
+#define TT_ERR                          ((knh_token_t)110)
 #define knh_Token_isERR(tk_)            (SP(tk_)->tt == TT_ERR)
-#define TT_EOT                          ((knh_token_t)108)
+#define TT_EOT                          ((knh_token_t)111)
 #define knh_Token_isEOT(tk_)            (SP(tk_)->tt == TT_EOT)
-#define KNH_TOKEN_MAXSIZ                ((knh_token_t)109)
+#define KNH_TOKEN_MAXSIZ                ((knh_token_t)112)
 
 /* ------------------------------------------------------------------------ */
+#ifndef METHODN_opALT
+#define METHODN_opALT                   METHODN_NONAME
+#endif
 #ifndef METHODN_opNot
 #define METHODN_opNot                   METHODN_NONAME
 #endif
@@ -246,9 +252,6 @@ extern "C" {
 #ifndef METHODN_opLand
 #define METHODN_opLand                  METHODN_NONAME
 #endif
-#ifndef METHODN_opALT
-#define METHODN_opALT                   METHODN_NONAME
-#endif
 #ifndef METHODN_opLnot
 #define METHODN_opLnot                  METHODN_NONAME
 #endif
@@ -261,6 +264,9 @@ extern "C" {
 #ifndef METHODN_opPrev
 #define METHODN_opPrev                  METHODN_NONAME
 #endif
+#ifndef METHODN_opNeg
+#define METHODN_opNeg                   METHODN_NONAME
+#endif
 
 /* ------------------------------------------------------------------------ */
 
@@ -292,37 +298,39 @@ extern "C" {
 #define STT_ASPECT                      ((knh_stmt_t)23)
 #define STT_IF                          ((knh_stmt_t)24)
 #define STT_ELSE                        ((knh_stmt_t)25)
-#define STT_WHILE                       ((knh_stmt_t)26)
-#define STT_DO                          ((knh_stmt_t)27)
-#define STT_FOR                         ((knh_stmt_t)28)
-#define STT_FOREACH                     ((knh_stmt_t)29)
-#define STT_FROM                        ((knh_stmt_t)30)
-#define STT_WHERE                       ((knh_stmt_t)31)
-#define STT_BREAK                       ((knh_stmt_t)32)
-#define STT_CONTINUE                    ((knh_stmt_t)33)
-#define STT_GOTO                        ((knh_stmt_t)34)
-#define STT_TRY                         ((knh_stmt_t)35)
-#define STT_CATCH                       ((knh_stmt_t)36)
-#define STT_FINALLY                     ((knh_stmt_t)37)
-#define STT_THROW                       ((knh_stmt_t)38)
-#define STT_ERR                         ((knh_stmt_t)39)
-#define STT_LET                         ((knh_stmt_t)40)
-#define STT_LETMULTI                    ((knh_stmt_t)41)
-#define STT_NEW                         ((knh_stmt_t)42)
-#define STT_MAPCAST                     ((knh_stmt_t)43)
-#define STT_CALL                        ((knh_stmt_t)44)
-#define STT_CALL1                       ((knh_stmt_t)45)
-#define STT_PCALL                       ((knh_stmt_t)46)
-#define STT_MT                          ((knh_stmt_t)47)
-#define STT_OP                          ((knh_stmt_t)48)
-#define STT_TRINARY                     ((knh_stmt_t)49)
-#define STT_ALT                         ((knh_stmt_t)50)
-#define STT_AND                         ((knh_stmt_t)51)
-#define STT_OR                          ((knh_stmt_t)52)
-#define STT_PRINT                       ((knh_stmt_t)53)
-#define STT_ASSERT                      ((knh_stmt_t)54)
-#define STT_MAN                         ((knh_stmt_t)55)
-#define KNH_STMT_MAXSIZ                 ((knh_stmt_t)56)
+#define STT_SWITCH                      ((knh_stmt_t)26)
+#define STT_CASE                        ((knh_stmt_t)27)
+#define STT_WHILE                       ((knh_stmt_t)28)
+#define STT_DO                          ((knh_stmt_t)29)
+#define STT_FOR                         ((knh_stmt_t)30)
+#define STT_FOREACH                     ((knh_stmt_t)31)
+#define STT_FROM                        ((knh_stmt_t)32)
+#define STT_WHERE                       ((knh_stmt_t)33)
+#define STT_BREAK                       ((knh_stmt_t)34)
+#define STT_CONTINUE                    ((knh_stmt_t)35)
+#define STT_GOTO                        ((knh_stmt_t)36)
+#define STT_TRY                         ((knh_stmt_t)37)
+#define STT_CATCH                       ((knh_stmt_t)38)
+#define STT_FINALLY                     ((knh_stmt_t)39)
+#define STT_THROW                       ((knh_stmt_t)40)
+#define STT_ERR                         ((knh_stmt_t)41)
+#define STT_LET                         ((knh_stmt_t)42)
+#define STT_LETMULTI                    ((knh_stmt_t)43)
+#define STT_NEW                         ((knh_stmt_t)44)
+#define STT_MAPCAST                     ((knh_stmt_t)45)
+#define STT_CALL                        ((knh_stmt_t)46)
+#define STT_CALL1                       ((knh_stmt_t)47)
+#define STT_PCALL                       ((knh_stmt_t)48)
+#define STT_MT                          ((knh_stmt_t)49)
+#define STT_OP                          ((knh_stmt_t)50)
+#define STT_TRINARY                     ((knh_stmt_t)51)
+#define STT_ALT                         ((knh_stmt_t)52)
+#define STT_AND                         ((knh_stmt_t)53)
+#define STT_OR                          ((knh_stmt_t)54)
+#define STT_PRINT                       ((knh_stmt_t)55)
+#define STT_ASSERT                      ((knh_stmt_t)56)
+#define STT_MAN                         ((knh_stmt_t)57)
+#define KNH_STMT_MAXSIZ                 ((knh_stmt_t)58)
 
 /* ------------------------------------------------------------------------ */
 
@@ -500,6 +508,16 @@ extern "C" {
 /* ======================================================================== */
 /* [else] */
 
+/* ======================================================================== */
+/* [switch] */
+#define StmtSWITCH_bool(stmt)           DP(stmt)->terms[0]
+#define SWITCH_bool                     0
+#define StmtSWITCH_case(stmt)           DP(stmt)->stmts[1]
+#define SWITCH_case                     1
+
+/* ======================================================================== */
+/* [case] */
+
 /* ======================================================================== */
 /* [while] */
 #define StmtWHILE_bool(stmt)            DP(stmt)->terms[0]
@@ -703,6 +721,8 @@ extern "C" {
 /* ======================================================================== */
 char* knh_token_tochar(knh_token_t t);
 knh_methodn_t knh_token_tomethodn(knh_token_t t);
+int knh_token_getOpPriority(knh_token_t t);
+int knh_token_getOpSize(knh_token_t t);
 knh_bool_t knh_token_isEndOfStmt(knh_token_t t);
 Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line_t line, knh_bytes_t token, BytesConv *bconv);
 int knh_bytes_istoken(knh_bytes_t t, int ch);
