@@ -38,7 +38,7 @@
 #define KONOHA_VERSION   PACKAGE_VERSION
 #else
 #define KONOHA_NAME     "konoha"
-#define KONOHA_VERSION  "0.1.4"
+#define KONOHA_VERSION  "0.1.5"
 #endif
 
 /* ======================================================================== */
@@ -69,7 +69,11 @@
 
 #ifdef __GNUC__
 	#define KONOHA_CC_VERSION __VERSION__
-	#define KNH_CC_FASTCALL   __attribute__((fastcall))
+	#ifdef __i386__
+		#define KNH_CC_FASTCALL   __attribute__((fastcall))
+	#else
+		#define KNH_CC_FASTCALL   /* __attribute__((fastcall)) */
+	#endif
 	#define KNH_CC_LABELPTR   1
 	#ifndef KONOHA_OS
 		#ifdef __linux__
