@@ -18,7 +18,9 @@
 #define		KNH_USING_POSIX 1
 #define		KNH_USING_UNIX  1
 #define		KONOHA_OS_ENCODING "UTF-8"
-#define         KNH_USING_ICONV 1
+#ifdef HAVE_ICONV_H
+#define		KNH_USING_ICONV 1
+#endif
 #define		KONOHA_OS_LINEFEED "\n"
 #define		KONOHA_OS_DLLEXT   ".so"
 #ifdef KONOHA_CC_WITH_ECLIPSE
@@ -65,6 +67,11 @@
 #define 	KNHAPI(T) __declspec(dllexport) T __stdcall
 #endif
 #define KONOHA_OS_DLLEXT ".dll"
+
+#ifndef HAVE_CONFIG_H
+#define KNH_USING_ICONV       1
+#define HAVE_LOCALCHARSET_H   1
+#endif
 #endif
 
 #ifdef KONOHA_OS__CYGWIN
@@ -72,7 +79,7 @@
 #define 	KNH_USING_UNIX     1
 #define 	KNH_USING_REGEX    1
 #define 	KONOHA_OS_LINEFEED "\r\n"
-#define 	KONOHA_OS_DLLEXT ".dll"
+#define 	KONOHA_OS_DLLEXT ".dll.a"
 #endif
 
 /* ======================================================================== */
@@ -102,7 +109,7 @@
 /* ======================================================================== */
 /* [CONFIG_H] */
 
-#if !defined(KNH_USING_ICONV) && defined(HAVE_LIBICONV)
+#if !defined(KNH_USING_ICONV) && defined(HAVE_ICONV_H)
 #define 	KNH_USING_ICONV 1
 #endif
 
