@@ -207,6 +207,41 @@ typedef unsigned long long int         knh_uint64_t;
 #define KNH_ULONG_MAX  ULLONG_MAX
 #define KNH_ULONG_MIN  ((knh_uint64_t)0)
 
+/* ------------------------------------------------------------------------ */
+/* Integer, knh_integer_t */
+/* ------------------------------------------------------------------------ */
+
+#ifdef KNH_USING_INT64
+#define knh_integer_t    knh_int64_t
+#define knh_uinteger_t   knh_uint64_t
+
+#define KNH_INTEGER_MAX               LLONG_MAX
+#define KNH_INTEGER_MIN               LLONG_MIN
+#define KNH_INTEGER_FMT               "%lld"
+#define KNH_INTEGER_FMTX              "%llx"
+#define KNH_INTEGER_BSIZE             (sizeof(knh_int_t))
+#define KNH_INTEGER_FMTSIZ            40
+#define KNH_UINTEGER_MAX              ULLONG_MAX
+#define KNH_UINTEGER_MIN              0
+#define KNH_UINTEGER_FMT              "%llu"
+
+#else /*KNH_USING_INT64*/
+
+#define knh_integer_t    knh_int_t
+#define knh_uinteger_t   knh_uint_t
+
+#define KNH_INTEGER_MAX               LONG_MAX
+#define KNH_INTEGER_MIN               LONG_MIN
+#define KNH_INTEGER_FMT               "%ld"
+#define KNH_INTEGER_FMTX              "%lx"
+#define KNH_INTEGER_BSIZE             (sizeof(knh_int_t))
+#define KNH_INTEGER_FMTSIZ            40
+#define KNH_UINTEGER_MAX              ULONG_MAX
+#define KNH_UINTEGER_MIN              0
+#define KNH_UINTEGER_FMT              "%lu"
+
+#endif/*KNH_USING_INT64*/
+
 /* ------------------------------------------------------------------------ */
 /* String, knh_uchar_t */
 /* ------------------------------------------------------------------------ */
@@ -413,6 +448,8 @@ typedef struct {
 
 /* ------------------------------------------------------------------------ */
 
+
+
 /* ------------------------------------------------------------------------ */
 
 typedef knh_uint_t                knh_vargc_t;
