@@ -54,6 +54,8 @@ static char* knh_token_array_tochar[] = {
     "aspect",  /* aspect */ 
     "if",  /* if */ 
     "else",  /* else */ 
+    "switch",  /* switch */ 
+    "case",  /* case */ 
     "while",  /* while */ 
     "do",  /* do */ 
     "for",  /* for */ 
@@ -91,6 +93,7 @@ static char* knh_token_array_tochar[] = {
     "..<",  /* SUBSET */ 
     "..+",  /* OFFSET */ 
     ":",  /* COLON */ 
+    "?\?",  /* ALT */ 
     "||",  /* OR */ 
     "&&",  /* AND */ 
     "!",  /* Not */ 
@@ -116,11 +119,11 @@ static char* knh_token_array_tochar[] = {
     "%",  /* Mod */ 
     "*",  /* Mul */ 
     "&",  /* Land */ 
-    "?\?",  /* ALT */ 
     "~",  /* Lnot */ 
     "^",  /* Xor */ 
     "++",  /* Next */ 
     "--",  /* Prev */ 
+    "---",  /* Neg */ 
     "NUM",  /* NUM */ 
     "STR",  /* STR */ 
     "TSTR",  /* TSTR */ 
@@ -152,7 +155,7 @@ static char* knh_token_array_tochar[] = {
 
 char* knh_token_tochar(knh_token_t t)
 {
-    DEBUG_ASSERT(t < KNH_TOKEN_MAXSIZ);
+    KNH_ASSERT(t < KNH_TOKEN_MAXSIZ);
     return knh_token_array_tochar[t];
 }
 
@@ -175,6 +178,8 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* aspect */ 
     METHODN_NONAME,  /* if */ 
     METHODN_NONAME,  /* else */ 
+    METHODN_NONAME,  /* switch */ 
+    METHODN_NONAME,  /* case */ 
     METHODN_NONAME,  /* while */ 
     METHODN_NONAME,  /* do */ 
     METHODN_NONAME,  /* for */ 
@@ -212,6 +217,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* SUBSET */ 
     METHODN_NONAME,  /* OFFSET */ 
     METHODN_NONAME,  /* COLON */ 
+    METHODN_opALT,  /* ALT */ 
     METHODN_NONAME,  /* OR */ 
     METHODN_NONAME,  /* AND */ 
     METHODN_opNot,  /* Not */ 
@@ -237,11 +243,11 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_opMod,  /* Mod */ 
     METHODN_opMul,  /* Mul */ 
     METHODN_opLand,  /* Land */ 
-    METHODN_opALT,  /* ALT */ 
     METHODN_opLnot,  /* Lnot */ 
     METHODN_opXor,  /* Xor */ 
     METHODN_opNext,  /* Next */ 
     METHODN_opPrev,  /* Prev */ 
+    METHODN_opNeg,  /* Neg */ 
     METHODN_NONAME,  /* NUM */ 
     METHODN_NONAME,  /* STR */ 
     METHODN_NONAME,  /* TSTR */ 
@@ -273,12 +279,260 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
 
 knh_methodn_t knh_token_tomethodn(knh_token_t t)
 {
-    DEBUG_ASSERT(t < KNH_TOKEN_MAXSIZ);
+    KNH_ASSERT(t < KNH_TOKEN_MAXSIZ);
     return knh_token_array_tomethodn[t];
 }
 
 /* ------------------------------------------------------------------------ */
 
+static int knh_token_array_getOpPriority[] = {
+    0,  /* namespace */ 
+    0,  /* import */ 
+    0,  /* pragma */ 
+    0,  /* using */ 
+    0,  /* with */ 
+    0,  /* class */ 
+    0,  /* extends */ 
+    0,  /* implements */ 
+    0,  /* method */ 
+    0,  /* format */ 
+    0,  /* return */ 
+    0,  /* mapmap */ 
+    0,  /* weave */ 
+    0,  /* aspect */ 
+    0,  /* if */ 
+    0,  /* else */ 
+    0,  /* switch */ 
+    0,  /* case */ 
+    0,  /* while */ 
+    0,  /* do */ 
+    0,  /* for */ 
+    0,  /* foreach */ 
+    0,  /* from */ 
+    0,  /* where */ 
+    0,  /* break */ 
+    0,  /* continue */ 
+    0,  /* goto */ 
+    0,  /* try */ 
+    0,  /* catch */ 
+    0,  /* finally */ 
+    0,  /* throw */ 
+    0,  /* print */ 
+    0,  /* assert */ 
+    99,  /* BRACE */ 
+    99,  /* PARENTHESIS */ 
+    99,  /* BRANCET */ 
+    0,  /* DOTS */ 
+    0,  /* SEMICOLON */ 
+    0,  /* COMMA */ 
+    0,  /* LET */ 
+    0,  /* lshifte */ 
+    0,  /* rshifte */ 
+    0,  /* adde */ 
+    0,  /* sube */ 
+    0,  /* mule */ 
+    0,  /* dive */ 
+    0,  /* mode */ 
+    0,  /* bitore */ 
+    0,  /* bitande */ 
+    0,  /* ALTLET */ 
+    2,  /* QUESTION */ 
+    2,  /* SUBSETE */ 
+    2,  /* SUBSET */ 
+    2,  /* OFFSET */ 
+    2,  /* COLON */ 
+    2,  /* ALT */ 
+    5,  /* OR */ 
+    6,  /* AND */ 
+    7,  /* Not */ 
+    9,  /* Instanceof */ 
+    9,  /* Isa */ 
+    9,  /* As */ 
+    9,  /* Has */ 
+    9,  /* Is */ 
+    9,  /* To */ 
+    9,  /* Eq */ 
+    9,  /* Neq */ 
+    9,  /* Lt */ 
+    9,  /* Lte */ 
+    9,  /* Gt */ 
+    9,  /* Gte */ 
+    11,  /* Lor */ 
+    12,  /* Fmt */ 
+    15,  /* Lshift */ 
+    15,  /* Rshift */ 
+    20,  /* Add */ 
+    20,  /* Sub */ 
+    24,  /* Div */ 
+    24,  /* Mod */ 
+    24,  /* Mul */ 
+    27,  /* Land */ 
+    27,  /* Lnot */ 
+    27,  /* Xor */ 
+    28,  /* Next */ 
+    28,  /* Prev */ 
+    28,  /* Neg */ 
+    99,  /* NUM */ 
+    99,  /* STR */ 
+    99,  /* TSTR */ 
+    99,  /* FMTSTR */ 
+    0,  /* LABEL */ 
+    0,  /* METAN */ 
+    99,  /* PROPN */ 
+    99,  /* URN */ 
+    99,  /* MT */ 
+    99,  /* CONSTN */ 
+    99,  /* TYPEN */ 
+    99,  /* CMETHODN */ 
+    99,  /* NAME */ 
+    99,  /* MN */ 
+    99,  /* FN */ 
+    99,  /* CID */ 
+    99,  /* CONST */ 
+    99,  /* MTDMPR */ 
+    99,  /* EBPIDX */ 
+    99,  /* SFPIDX */ 
+    99,  /* FLDIDX */ 
+    99,  /* OBJIDX */ 
+    99,  /* SYSCONST */ 
+    0,  /* ASIS */ 
+    0,  /* ERR */ 
+    0,  /* EOT */ 
+    //(int)0
+};
+
+int knh_token_getOpPriority(knh_token_t t)
+{
+    KNH_ASSERT(t < KNH_TOKEN_MAXSIZ);
+    return knh_token_array_getOpPriority[t];
+}
+
+/* ------------------------------------------------------------------------ */
+
+static int knh_token_array_getOpSize[] = {
+    0,  /* namespace */ 
+    0,  /* import */ 
+    0,  /* pragma */ 
+    0,  /* using */ 
+    0,  /* with */ 
+    0,  /* class */ 
+    0,  /* extends */ 
+    0,  /* implements */ 
+    0,  /* method */ 
+    0,  /* format */ 
+    0,  /* return */ 
+    0,  /* mapmap */ 
+    0,  /* weave */ 
+    0,  /* aspect */ 
+    0,  /* if */ 
+    0,  /* else */ 
+    0,  /* switch */ 
+    0,  /* case */ 
+    0,  /* while */ 
+    0,  /* do */ 
+    0,  /* for */ 
+    0,  /* foreach */ 
+    0,  /* from */ 
+    0,  /* where */ 
+    0,  /* break */ 
+    0,  /* continue */ 
+    0,  /* goto */ 
+    0,  /* try */ 
+    0,  /* catch */ 
+    0,  /* finally */ 
+    0,  /* throw */ 
+    0,  /* print */ 
+    0,  /* assert */ 
+    0,  /* BRACE */ 
+    0,  /* PARENTHESIS */ 
+    0,  /* BRANCET */ 
+    0,  /* DOTS */ 
+    0,  /* SEMICOLON */ 
+    0,  /* COMMA */ 
+    0,  /* LET */ 
+    0,  /* lshifte */ 
+    0,  /* rshifte */ 
+    0,  /* adde */ 
+    0,  /* sube */ 
+    0,  /* mule */ 
+    0,  /* dive */ 
+    0,  /* mode */ 
+    0,  /* bitore */ 
+    0,  /* bitande */ 
+    0,  /* ALTLET */ 
+    0,  /* QUESTION */ 
+    0,  /* SUBSETE */ 
+    0,  /* SUBSET */ 
+    0,  /* OFFSET */ 
+    0,  /* COLON */ 
+    0,  /* ALT */ 
+    0,  /* OR */ 
+    0,  /* AND */ 
+    1,  /* Not */ 
+    2,  /* Instanceof */ 
+    2,  /* Isa */ 
+    2,  /* As */ 
+    2,  /* Has */ 
+    2,  /* Is */ 
+    2,  /* To */ 
+    2,  /* Eq */ 
+    2,  /* Neq */ 
+    2,  /* Lt */ 
+    2,  /* Lte */ 
+    2,  /* Gt */ 
+    2,  /* Gte */ 
+    0,  /* Lor */ 
+    2,  /* Fmt */ 
+    0,  /* Lshift */ 
+    0,  /* Rshift */ 
+    0,  /* Add */ 
+    2,  /* Sub */ 
+    2,  /* Div */ 
+    2,  /* Mod */ 
+    2,  /* Mul */ 
+    0,  /* Land */ 
+    1,  /* Lnot */ 
+    2,  /* Xor */ 
+    1,  /* Next */ 
+    1,  /* Prev */ 
+    1,  /* Neg */ 
+    0,  /* NUM */ 
+    0,  /* STR */ 
+    0,  /* TSTR */ 
+    0,  /* FMTSTR */ 
+    0,  /* LABEL */ 
+    0,  /* METAN */ 
+    0,  /* PROPN */ 
+    0,  /* URN */ 
+    0,  /* MT */ 
+    0,  /* CONSTN */ 
+    0,  /* TYPEN */ 
+    0,  /* CMETHODN */ 
+    0,  /* NAME */ 
+    0,  /* MN */ 
+    0,  /* FN */ 
+    0,  /* CID */ 
+    0,  /* CONST */ 
+    0,  /* MTDMPR */ 
+    0,  /* EBPIDX */ 
+    0,  /* SFPIDX */ 
+    0,  /* FLDIDX */ 
+    0,  /* OBJIDX */ 
+    0,  /* SYSCONST */ 
+    0,  /* ASIS */ 
+    0,  /* ERR */ 
+    0,  /* EOT */ 
+    //(int)0
+};
+
+int knh_token_getOpSize(knh_token_t t)
+{
+    KNH_ASSERT(t < KNH_TOKEN_MAXSIZ);
+    return knh_token_array_getOpSize[t];
+}
+
+/* ------------------------------------------------------------------------ */
+
 static knh_bool_t knh_token_array_isEndOfStmt[] = {
     1,  /* namespace */ 
     1,  /* import */ 
@@ -296,6 +550,8 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     1,  /* aspect */ 
     1,  /* if */ 
     1,  /* else */ 
+    1,  /* switch */ 
+    1,  /* case */ 
     1,  /* while */ 
     1,  /* do */ 
     1,  /* for */ 
@@ -333,6 +589,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     0,  /* SUBSET */ 
     0,  /* OFFSET */ 
     0,  /* COLON */ 
+    0,  /* ALT */ 
     0,  /* OR */ 
     0,  /* AND */ 
     0,  /* Not */ 
@@ -358,11 +615,11 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     0,  /* Mod */ 
     0,  /* Mul */ 
     0,  /* Land */ 
-    0,  /* ALT */ 
     0,  /* Lnot */ 
     0,  /* Xor */ 
     0,  /* Next */ 
     0,  /* Prev */ 
+    0,  /* Neg */ 
     0,  /* NUM */ 
     0,  /* STR */ 
     0,  /* TSTR */ 
@@ -394,7 +651,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
 
 knh_bool_t knh_token_isEndOfStmt(knh_token_t t)
 {
-    DEBUG_ASSERT(t < KNH_TOKEN_MAXSIZ);
+    KNH_ASSERT(t < KNH_TOKEN_MAXSIZ);
     return knh_token_array_isEndOfStmt[t];
 }
 
@@ -471,6 +728,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
         if(ISB(t, "-->")) { tt = TT_TO; break; }
         if(ISB(t, "-")) { tt = TT_SUB; break; }
         if(ISB(t, "--")) { tt = TT_PREV; break; }
+        if(ISB(t, "---")) { tt = TT_NEG; break; }
     break;
     case '.':
         if(ISB(t, "...")) { tt = TT_DOTS; break; }
@@ -548,6 +806,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
     break;
     case 'c':
         if(ISB(t, "class")) { tt = TT_CLASS; break; }
+        if(ISB(t, "case")) { tt = TT_CASE; break; }
         if(ISB(t, "continue")) { tt = TT_CONTINUE; break; }
         if(ISB(t, "catch")) { tt = TT_CATCH; break; }
         if(ISB(t, "const")) { tt = TT_METAN; break; }
@@ -585,7 +844,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
         if(ISB(t, "int")) { t = STEXT("Int!"); goto L_TAIL; }
     break;
     case 'l':
-        if(ISB(t, "long")) { t = STEXT("Int64!"); goto L_TAIL; }
+        if(ISB(t, "long")) { t = STEXT("Int!"); goto L_TAIL; }
     break;
     case 'm':
         if(ISB(t, "method")) { tt = TT_METHOD; break; }
@@ -609,6 +868,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line
         if(ISB(t, "return")) { tt = TT_RETURN; break; }
     break;
     case 's':
+        if(ISB(t, "switch")) { tt = TT_SWITCH; break; }
         if(ISB(t, "static")) { tt = TT_METAN; break; }
     break;
     case 't':
@@ -672,6 +932,7 @@ int knh_bytes_istoken(knh_bytes_t t, int ch)
         return 0; 
     case '-':
         if(ISB(t, "-")) { return 1; }
+        if(ISB(t, "--")) { return 1; }
         return 0; 
     case '.':
         if(ISB(t, "..")) { return 1; }
@@ -703,11 +964,11 @@ int knh_bytes_istoken(knh_bytes_t t, int ch)
         if(ISB(t, ">")) { return 1; }
         return 0; 
     case '?':
+        if(ISB(t, "?")) { return 1; }
         if(ISB(t, "isa")) { return 1; }
         if(ISB(t, "in")) { return 1; }
         if(ISB(t, "is")) { return 1; }
         if(ISB(t, "to")) { return 1; }
-        if(ISB(t, "?")) { return 1; }
         return 0; 
     case '|':
         if(ISB(t, "|")) { return 1; }
@@ -747,6 +1008,8 @@ static char* knh_stmt_array_tochar[] = {
     "aspect",  /* aspect */ 
     "if",  /* if */ 
     "else",  /* else */ 
+    "switch",  /* switch */ 
+    "case",  /* case */ 
     "while",  /* while */ 
     "do",  /* do */ 
     "for",  /* for */ 
@@ -782,7 +1045,7 @@ static char* knh_stmt_array_tochar[] = {
 
 char* knh_stmt_tochar(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_tochar[t];
 }
 
@@ -815,6 +1078,8 @@ static size_t knh_stmt_array_size[] = {
     5,  /* aspect */ 
     3,  /* if */ 
     0,  /* else */ 
+    2,  /* switch */ 
+    0,  /* case */ 
     2,  /* while */ 
     2,  /* do */ 
     4,  /* for */ 
@@ -850,7 +1115,7 @@ static size_t knh_stmt_array_size[] = {
 
 size_t knh_stmt_size(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_size[t];
 }
 
@@ -1210,6 +1475,20 @@ static Stmt *new_StmtIF(Ctx *ctx, knh_tokens_t *tc)
 
 /* ------------------------------------------------------------------------ */
 
+/* ------------------------------------------------------------------------ */
+/* [switch] */
+
+static Stmt *new_StmtSWITCH(Ctx *ctx, knh_tokens_t *tc)
+{
+	Stmt *o = new_Stmt(ctx, 0, STT_SWITCH);
+	knh_StmtMETA_add_prestmt(ctx, o, tc, -2);
+	knh_Stmt_add_PEXPR(ctx, o, tc); /* pexpr */
+	knh_Stmt_add_STMT1(ctx, o, tc); /* { */
+	return o;
+}
+
+/* ------------------------------------------------------------------------ */
+
 /* ------------------------------------------------------------------------ */
 /* [while] */
 
@@ -1425,6 +1704,10 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
         return new_StmtIF(ctx, tc);
     case TT_ELSE:  /* else */
         break;
+    case TT_SWITCH: 
+        return new_StmtSWITCH(ctx, tc);
+    case TT_CASE:  /* case */
+        break;
     case TT_WHILE: 
         return new_StmtWHILE(ctx, tc);
     case TT_DO: 
@@ -1503,6 +1786,8 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
         break;
     case TT_COLON:  /* COLON */
         break;
+    case TT_ALT:  /* ALT */
+        break;
     case TT_OR:  /* OR */
         break;
     case TT_AND:  /* AND */
@@ -1558,8 +1843,6 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
     case TT_LAND:  /* Land */
         tc->c -= 1;
         return new_StmtFUNCEXPR(ctx, tc);
-    case TT_ALT:  /* ALT */
-        break;
     case TT_LNOT:  /* Lnot */
         tc->c -= 1;
         return new_StmtFUNCEXPR(ctx, tc);
@@ -1572,6 +1855,9 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
     case TT_PREV:  /* Prev */
         tc->c -= 1;
         return new_StmtFUNCEXPR(ctx, tc);
+    case TT_NEG:  /* Neg */
+        tc->c -= 1;
+        return new_StmtFUNCEXPR(ctx, tc);
     case TT_NUM:  /* NUM */
         tc->c -= 1;
         return new_StmtFUNCEXPR(ctx, tc);
@@ -1696,6 +1982,8 @@ static int knh_stmt_array_isExpr[] = {
     0,  /* aspect */ 
     0,  /* if */ 
     0,  /* else */ 
+    0,  /* switch */ 
+    0,  /* case */ 
     0,  /* while */ 
     0,  /* do */ 
     0,  /* for */ 
@@ -1731,7 +2019,7 @@ static int knh_stmt_array_isExpr[] = {
 
 int knh_stmt_isExpr(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_isExpr[t];
 }
 
@@ -1764,6 +2052,8 @@ static f_visitdecl knh_stmt_array_decl[] = {
     knh_StmtDONE_decl,  /* aspect */ 
     knh_StmtDONE_decl,  /* if */ 
     knh_StmtDONE_decl,  /* else */ 
+    knh_StmtDONE_decl,  /* switch */ 
+    knh_StmtDONE_decl,  /* case */ 
     knh_StmtDONE_decl,  /* while */ 
     knh_StmtDONE_decl,  /* do */ 
     knh_StmtDONE_decl,  /* for */ 
@@ -1799,7 +2089,7 @@ static f_visitdecl knh_stmt_array_decl[] = {
 
 f_visitdecl knh_stmt_decl(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_decl[t];
 }
 
@@ -1832,6 +2122,8 @@ static f_visitname knh_stmt_array_name[] = {
     knh_StmtDONE_name,  /* aspect */ 
     knh_StmtIF_name,  /* if */ 
     knh_StmtDONE_name,  /* else */ 
+    knh_StmtSWITCH_name,  /* switch */ 
+    knh_StmtDONE_name,  /* case */ 
     knh_StmtWHILE_name,  /* while */ 
     knh_StmtDO_name,  /* do */ 
     knh_StmtFOR_name,  /* for */ 
@@ -1841,10 +2133,10 @@ static f_visitname knh_stmt_array_name[] = {
     knh_StmtDONE_name,  /* break */ 
     knh_StmtDONE_name,  /* continue */ 
     knh_StmtDONE_name,  /* goto */ 
-    knh_StmtDONE_name,  /* try */ 
+    knh_StmtTRY_name,  /* try */ 
     knh_StmtDONE_name,  /* catch */ 
     knh_StmtDONE_name,  /* finally */ 
-    knh_StmtDONE_name,  /* throw */ 
+    knh_StmtTHROW_name,  /* throw */ 
     knh_StmtDONE_name,  /* err */ 
     knh_StmtLET_name,  /* let */ 
     knh_StmtDONE_name,  /* letmulti */ 
@@ -1867,7 +2159,7 @@ static f_visitname knh_stmt_array_name[] = {
 
 f_visitname knh_stmt_name(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_name[t];
 }
 
@@ -1900,6 +2192,8 @@ static f_visitcmpl knh_stmt_array_cmpl[] = {
     knh_StmtDONE_cmpl,  /* aspect */ 
     knh_StmtIF_cmpl,  /* if */ 
     knh_StmtDONE_cmpl,  /* else */ 
+    knh_StmtSWITCH_cmpl,  /* switch */ 
+    knh_StmtDONE_cmpl,  /* case */ 
     knh_StmtWHILE_cmpl,  /* while */ 
     knh_StmtDO_cmpl,  /* do */ 
     knh_StmtFOR_cmpl,  /* for */ 
@@ -1909,10 +2203,10 @@ static f_visitcmpl knh_stmt_array_cmpl[] = {
     knh_StmtBREAK_cmpl,  /* break */ 
     knh_StmtCONTINUE_cmpl,  /* continue */ 
     knh_StmtGOTO_cmpl,  /* goto */ 
-    knh_StmtDONE_cmpl,  /* try */ 
+    knh_StmtTRY_cmpl,  /* try */ 
     knh_StmtDONE_cmpl,  /* catch */ 
     knh_StmtDONE_cmpl,  /* finally */ 
-    knh_StmtDONE_cmpl,  /* throw */ 
+    knh_StmtTHROW_cmpl,  /* throw */ 
     knh_StmtERR_cmpl,  /* err */ 
     knh_StmtLET_cmpl,  /* let */ 
     knh_StmtDONE_cmpl,  /* letmulti */ 
@@ -1935,7 +2229,7 @@ static f_visitcmpl knh_stmt_array_cmpl[] = {
 
 f_visitcmpl knh_stmt_cmpl(knh_stmt_t t)
 {
-    DEBUG_ASSERT(t < KNH_STMT_MAXSIZ);
+    KNH_ASSERT(t < KNH_STMT_MAXSIZ);
     return knh_stmt_array_cmpl[t];
 }
 
